/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FL3NGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FL3NGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FL3NGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FL3NGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FL3NGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FL3NGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FL3NGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FL3NGR::Heavy_WSTD_FL3NGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_h9XYNFRf);
  numBytes += sLine_init(&sLine_wBM5C2iq);
  numBytes += sLine_init(&sLine_E10YTG2v);
  numBytes += sLine_init(&sLine_FP1y673P);
  numBytes += sLine_init(&sLine_HIYJ00HM);
  numBytes += sBiquad_init(&sBiquad_s_FRtlYWeK);
  numBytes += sLine_init(&sLine_fUcCzQbt);
  numBytes += sLine_init(&sLine_gtqpY1Mq);
  numBytes += sLine_init(&sLine_k8b47TYc);
  numBytes += sLine_init(&sLine_624nJyVR);
  numBytes += sBiquad_init(&sBiquad_s_YEXqnzgC);
  numBytes += sLine_init(&sLine_TmqnO8TC);
  numBytes += sLine_init(&sLine_dDME5tZl);
  numBytes += sLine_init(&sLine_17mxWgEB);
  numBytes += sLine_init(&sLine_hXN8FsA3);
  numBytes += sLine_init(&sLine_59pETihH);
  numBytes += sBiquad_init(&sBiquad_s_962gDsHJ);
  numBytes += sLine_init(&sLine_Aktkxcce);
  numBytes += sLine_init(&sLine_3mHnlXnM);
  numBytes += sLine_init(&sLine_P91c108O);
  numBytes += sLine_init(&sLine_gikfnGzI);
  numBytes += sLine_init(&sLine_iTgM2ijW);
  numBytes += sBiquad_init(&sBiquad_s_p6zxscl9);
  numBytes += sLine_init(&sLine_EJoJnBJt);
  numBytes += sLine_init(&sLine_lPsLHcxU);
  numBytes += sLine_init(&sLine_9z8jmUoA);
  numBytes += sLine_init(&sLine_DaCKeQfS);
  numBytes += sBiquad_init(&sBiquad_s_g4MB6TXs);
  numBytes += sLine_init(&sLine_ALBNZ6Ug);
  numBytes += sLine_init(&sLine_Rw3MiDJA);
  numBytes += sLine_init(&sLine_PDUR6Oga);
  numBytes += sLine_init(&sLine_aFHpFC2I);
  numBytes += sLine_init(&sLine_DBepuiNk);
  numBytes += sBiquad_init(&sBiquad_s_eSkh65fu);
  numBytes += sLine_init(&sLine_e5nphpH0);
  numBytes += sPhasor_k_init(&sPhasor_Esxz9yMm, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_9wcXf5TC);
  numBytes += sRPole_init(&sRPole_mFIqWPRb);
  numBytes += sRPole_init(&sRPole_1rf5yC0Y);
  numBytes += sTabhead_init(&sTabhead_FifwOZDR, &hTable_0xQ7THyn);
  numBytes += sTabread_init(&sTabread_oTzaTaVy, &hTable_0xQ7THyn, false);
  numBytes += sTabread_init(&sTabread_gLN0mO8w, &hTable_0xQ7THyn, false);
  numBytes += sLine_init(&sLine_S2TmLJbK);
  numBytes += sTabhead_init(&sTabhead_OiI1gBY8, &hTable_0kXJuzoT);
  numBytes += sTabread_init(&sTabread_B1lWH8Te, &hTable_0kXJuzoT, false);
  numBytes += sTabread_init(&sTabread_hUUPpvUZ, &hTable_0kXJuzoT, false);
  numBytes += sLine_init(&sLine_cmEIlbXH);
  numBytes += sTabwrite_init(&sTabwrite_LRwvX4DO, &hTable_0kXJuzoT);
  numBytes += sTabwrite_init(&sTabwrite_4n3fj4yb, &hTable_0xQ7THyn);
  numBytes += sLine_init(&sLine_DP1WKi1L);
  numBytes += sPhasor_k_init(&sPhasor_k2ZN1e4W, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_UsJOItPc);
  numBytes += sRPole_init(&sRPole_ARzVmkKA);
  numBytes += sRPole_init(&sRPole_VgwjQd49);
  numBytes += sTabhead_init(&sTabhead_AzfW6dpt, &hTable_jPIHCBKs);
  numBytes += sTabread_init(&sTabread_eVCdCPUq, &hTable_jPIHCBKs, false);
  numBytes += sTabread_init(&sTabread_QsRoH593, &hTable_jPIHCBKs, false);
  numBytes += sLine_init(&sLine_fyLT8u6R);
  numBytes += sTabhead_init(&sTabhead_mnQ5iKXj, &hTable_fUllEQbq);
  numBytes += sTabread_init(&sTabread_Rv7TfEmu, &hTable_fUllEQbq, false);
  numBytes += sTabread_init(&sTabread_vC02TxmK, &hTable_fUllEQbq, false);
  numBytes += sLine_init(&sLine_FHjyf8fD);
  numBytes += sTabwrite_init(&sTabwrite_h4uV5VZS, &hTable_fUllEQbq);
  numBytes += sTabwrite_init(&sTabwrite_CYmqKX1m, &hTable_jPIHCBKs);
  numBytes += sLine_init(&sLine_MLud7rFv);
  numBytes += sPhasor_k_init(&sPhasor_PgQCWqpR, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_ow4dWtIc);
  numBytes += sRPole_init(&sRPole_4mvB96Ym);
  numBytes += sRPole_init(&sRPole_kY4qKT1f);
  numBytes += sTabhead_init(&sTabhead_rmOvLFDg, &hTable_exYt3KeQ);
  numBytes += sTabread_init(&sTabread_TnEmLToP, &hTable_exYt3KeQ, false);
  numBytes += sTabread_init(&sTabread_i1RmdziK, &hTable_exYt3KeQ, false);
  numBytes += sLine_init(&sLine_zehEva0Q);
  numBytes += sTabhead_init(&sTabhead_rCRrJcqw, &hTable_5mJknyI3);
  numBytes += sTabread_init(&sTabread_PKFILhJQ, &hTable_5mJknyI3, false);
  numBytes += sTabread_init(&sTabread_sitp6Qqk, &hTable_5mJknyI3, false);
  numBytes += sLine_init(&sLine_EqgGYvDv);
  numBytes += sTabwrite_init(&sTabwrite_gPeJCxYv, &hTable_5mJknyI3);
  numBytes += sTabwrite_init(&sTabwrite_rrn5iIFw, &hTable_exYt3KeQ);
  numBytes += cVar_init_f(&cVar_uVpAyZE8, 0.0f);
  numBytes += cVar_init_f(&cVar_zkFL5DoZ, 0.0f);
  numBytes += cVar_init_f(&cVar_vCJCIC6V, 0.0f);
  numBytes += cVar_init_f(&cVar_Evw0V7ZQ, 0.0f);
  numBytes += cSlice_init(&cSlice_hwO4KKDE, 1, -1);
  numBytes += cVar_init_f(&cVar_3L4XG43Q, 1337.0f);
  numBytes += cVar_init_f(&cVar_wMl3bmMU, 0.0f);
  numBytes += cIf_init(&cIf_4YE5GxH6, false);
  numBytes += cIf_init(&cIf_I39zfjGh, false);
  numBytes += cBinop_init(&cBinop_w0lGq554, 0.0f); // __pow
  numBytes += cIf_init(&cIf_oG1hVGPR, false);
  numBytes += cBinop_init(&cBinop_d1Bnl6VT, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YKWyTbOT, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_0C7fujE2, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_GDKgqdCZ, 0.0f);
  numBytes += cIf_init(&cIf_ceXYQvfq, false);
  numBytes += cIf_init(&cIf_yFCJY4Ck, false);
  numBytes += cBinop_init(&cBinop_DJwwkZkU, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ebslIM8B, false);
  numBytes += cBinop_init(&cBinop_UYzgP1Gc, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Hrm4LiJH, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Qm9UzVhZ, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_0yPe5rAz, 0.0f);
  numBytes += cIf_init(&cIf_ZfyvwuW9, false);
  numBytes += cIf_init(&cIf_oK8AR1i3, false);
  numBytes += cBinop_init(&cBinop_M0JGxcpj, 0.0f); // __pow
  numBytes += cIf_init(&cIf_UnnOSgZB, false);
  numBytes += cBinop_init(&cBinop_VyRcGUhg, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DZKPCiBB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_YCyHW7Av, -15.0f); // __eq
  numBytes += cIf_init(&cIf_3eL4ev8S, false);
  numBytes += cSlice_init(&cSlice_LiaSoMni, 1, -1);
  numBytes += cVar_init_f(&cVar_6chdap7p, 0.0f);
  numBytes += cSlice_init(&cSlice_Z3w3KCcN, 1, -1);
  numBytes += cVar_init_f(&cVar_P6L3Kqte, 0.0f);
  numBytes += cSlice_init(&cSlice_wgoEibuB, 1, -1);
  numBytes += cVar_init_f(&cVar_YPfyIPsZ, 0.0f);
  numBytes += cSlice_init(&cSlice_ia7lkMAs, 1, -1);
  numBytes += cVar_init_f(&cVar_1qsej3pM, 0.313f);
  numBytes += cBinop_init(&cBinop_ckFha73O, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_KZVTNpp7, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_uXujDCSY, 0.0f);
  numBytes += cVar_init_f(&cVar_fLEAIpyl, 1337.0f);
  numBytes += cVar_init_f(&cVar_BiwQBcv3, 0.3f);
  numBytes += cBinop_init(&cBinop_2Dsb2Fbs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rlGbCOPK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_niLrwmuy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cnofYmYW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lMLGqDGl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_snwYc2OZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RqNtR5Mn, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_OAcDKekE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_E2INXboP, 0.0f);
  numBytes += cVar_init_f(&cVar_wg7Jbenc, 1337.0f);
  numBytes += cVar_init_f(&cVar_2fm6PhxA, 0.313f);
  numBytes += cBinop_init(&cBinop_ss9NsmPM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jxyy9AKr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Oq2ktibC, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pCs9T8NP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gOzHpV1e, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vDj6jCaF, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_XpowOCxq, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dfXAb5j1, 0.0f);
  numBytes += cVar_init_f(&cVar_HYlG5tgN, 1037.0f);
  numBytes += cVar_init_f(&cVar_whRFX1VF, 0.4f);
  numBytes += cBinop_init(&cBinop_m0QIbzbE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NyyYyjRY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E2pTrHgO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SfYwkApE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6OemIwhR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_auw5EaDm, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_WPoutDy8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EvPReawm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dovMLsnx, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_2hmXqYra, 1, -1);
  numBytes += cVar_init_f(&cVar_d4KYBiIG, 1337.0f);
  numBytes += cVar_init_f(&cVar_8ihbOjID, 0.0f);
  numBytes += cIf_init(&cIf_e3RX29gX, false);
  numBytes += cIf_init(&cIf_3ImbbNQw, false);
  numBytes += cBinop_init(&cBinop_neNz1HJN, 0.0f); // __pow
  numBytes += cIf_init(&cIf_E68Ud8pC, false);
  numBytes += cBinop_init(&cBinop_00Fbllj5, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_rhAH4f88, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_EUccXcVW, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_7fAfAH0s, 0.0f);
  numBytes += cIf_init(&cIf_ss4xqlBX, false);
  numBytes += cIf_init(&cIf_vKzHaBkr, false);
  numBytes += cBinop_init(&cBinop_GlMWqLHU, 0.0f); // __pow
  numBytes += cIf_init(&cIf_59GMCRiF, false);
  numBytes += cBinop_init(&cBinop_uxcevUeP, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bVOcC9ki, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_cg2c8BvI, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_7Taz0BLy, 0.0f);
  numBytes += cIf_init(&cIf_dW2wAcK8, false);
  numBytes += cIf_init(&cIf_14VIHDVY, false);
  numBytes += cBinop_init(&cBinop_HSLOCPy4, 0.0f); // __pow
  numBytes += cIf_init(&cIf_bt8UhCdc, false);
  numBytes += cBinop_init(&cBinop_zSdNYO5K, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_DCKil0io, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_IkyDfFq0, -15.0f); // __eq
  numBytes += cIf_init(&cIf_AfsVxvqF, false);
  numBytes += cSlice_init(&cSlice_rwRUTak1, 1, -1);
  numBytes += cVar_init_f(&cVar_QBHJCxBU, 0.0f);
  numBytes += cSlice_init(&cSlice_mQQ6bIzu, 1, -1);
  numBytes += cVar_init_f(&cVar_kei45EjP, 0.0f);
  numBytes += cSlice_init(&cSlice_66yr5t2M, 1, -1);
  numBytes += cVar_init_f(&cVar_ZeIMwCRP, 0.0f);
  numBytes += cSlice_init(&cSlice_58fTYBs1, 1, -1);
  numBytes += cVar_init_f(&cVar_0g5of0Na, 0.313f);
  numBytes += cBinop_init(&cBinop_0lnRGjuJ, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_J6oXymrG, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_WqpWGzwj, 0.0f);
  numBytes += cVar_init_f(&cVar_8kVmapEU, 1337.0f);
  numBytes += cVar_init_f(&cVar_XPvewAJg, 0.3f);
  numBytes += cBinop_init(&cBinop_XU4G9YZ9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_S9W76vT7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KjAiwxzu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SguOs05E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_voEyL3If, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_I5h43v7P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NtBPcwFV, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Lbfx67nI, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_hUKFhVCF, 0.0f);
  numBytes += cVar_init_f(&cVar_ViQzFV0J, 1337.0f);
  numBytes += cVar_init_f(&cVar_3V5BzbEx, 0.313f);
  numBytes += cBinop_init(&cBinop_5Z2kHeBM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HMAf7Q0m, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2nNekXev, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_K5ZD4qH4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Xdvsp9wY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pE8LqVnw, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_gsG594lo, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_puXDRBaL, 0.0f);
  numBytes += cVar_init_f(&cVar_P1l6h1vb, 1037.0f);
  numBytes += cVar_init_f(&cVar_qEAn7wh9, 0.4f);
  numBytes += cBinop_init(&cBinop_PMlh3FMJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HqzeAWzq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_b3cjboZy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IE3ELBxV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qw1A3BQ2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SrcYyrCR, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_zazBS8NY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7jecEgCm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0VR2a120, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_8PBIqvX8, 5705.6f);
  numBytes += cVar_init_f(&cVar_ggbiZbu1, 313.3f);
  numBytes += cBinop_init(&cBinop_Rz72PXez, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_7q0dFfss, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_WCCfq3ci, 0.0f); // __div
  numBytes += cVar_init_f(&cVar_P1qC9Njg, 0.0f);
  numBytes += cVar_init_f(&cVar_GBb4yB8X, 0.0f);
  numBytes += cVar_init_f(&cVar_sp3YIHOX, 0.0f);
  numBytes += cVar_init_f(&cVar_TbHSNimL, 0.0f);
  numBytes += cVar_init_f(&cVar_QMuCi2lx, 0.0f);
  numBytes += cVar_init_f(&cVar_zQNoWIc4, 0.0f);
  numBytes += cVar_init_f(&cVar_2MCnAFpo, 0.0f);
  numBytes += cVar_init_f(&cVar_xYo12C79, 0.0f);
  numBytes += cVar_init_f(&cVar_jRp1SfMt, 0.0f);
  numBytes += cVar_init_f(&cVar_h6F9cas4, 0.0f);
  numBytes += cVar_init_f(&cVar_wIC8CdJB, 0.0f);
  numBytes += cVar_init_f(&cVar_GieRInnz, 0.0f);
  numBytes += cVar_init_s(&cVar_91G1z4Rr, "del-1348-flanger-l");
  numBytes += sVarf_init(&sVarf_wpfW3PB5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uDfhR1dW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VApOf2eL, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_aZMGsB6G, "del-1348-flanger-r");
  numBytes += sVarf_init(&sVarf_oojM5twO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RF5cQhEN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_15Y4tSEc, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_B6EciDim, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Sc5t7f50, 0.0f);
  numBytes += hTable_init(&hTable_0kXJuzoT, 256);
  numBytes += cDelay_init(this, &cDelay_WKdj8aDf, 0.0f);
  numBytes += cDelay_init(this, &cDelay_znabT3nG, 0.0f);
  numBytes += hTable_init(&hTable_0xQ7THyn, 256);
  numBytes += cVar_init_f(&cVar_uPUsXlgc, 14.0f);
  numBytes += cBinop_init(&cBinop_opK1bIcw, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_vTkzWq5v, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1KFBptOr, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_CVqxGADU, 14.0f);
  numBytes += cBinop_init(&cBinop_eOLR9Ffz, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_WNAgUhqY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l70seWgW, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_tXSEfczX, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_3obatd09, 1, -1);
  numBytes += cVar_init_f(&cVar_3HWrAzEc, 0.2f);
  numBytes += cSlice_init(&cSlice_JDd608YO, 1, -1);
  numBytes += cVar_init_f(&cVar_VMI6pSzx, 0.0f);
  numBytes += cSlice_init(&cSlice_ycHwTbsA, 1, -1);
  numBytes += cVar_init_f(&cVar_9PIynrgJ, 2.0f);
  numBytes += cSlice_init(&cSlice_uITReHf0, 1, -1);
  numBytes += cVar_init_f(&cVar_TTi9r5pC, 0.5f);
  numBytes += cVar_init_s(&cVar_nZRM7LoB, "del-1397-flanger-l");
  numBytes += sVarf_init(&sVarf_rMgXQ0Um, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rdmqZwk6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zz2fk708, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_sBJeMWkd, "del-1397-flanger-r");
  numBytes += sVarf_init(&sVarf_QHNN0mgH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qjpHCObj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0INIjNCr, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_HY1pfgEZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VKfwQCZE, 0.0f);
  numBytes += hTable_init(&hTable_fUllEQbq, 256);
  numBytes += cDelay_init(this, &cDelay_ENBXQCpc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9GP1ZNsn, 0.0f);
  numBytes += hTable_init(&hTable_jPIHCBKs, 256);
  numBytes += cVar_init_f(&cVar_zwONcVna, 14.0f);
  numBytes += cBinop_init(&cBinop_aHy2outF, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wR8eTwX5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_La8VuNlH, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Z8jSKoEL, 14.0f);
  numBytes += cBinop_init(&cBinop_22X70zpM, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fMrJgR9a, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AEAnBpC8, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_Io5eRgfO, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_Aht2PN5l, 1, -1);
  numBytes += cVar_init_f(&cVar_m5G3vjzU, 0.2f);
  numBytes += cSlice_init(&cSlice_lyqhmJo1, 1, -1);
  numBytes += cVar_init_f(&cVar_GXxn0b2l, 0.0f);
  numBytes += cSlice_init(&cSlice_lfAESBiO, 1, -1);
  numBytes += cVar_init_f(&cVar_SL2E4lXt, 2.0f);
  numBytes += cSlice_init(&cSlice_R20BOjbm, 1, -1);
  numBytes += cVar_init_f(&cVar_SEbAPOEw, 0.5f);
  numBytes += cVar_init_s(&cVar_Vjsxfq5i, "del-1446-flanger-l");
  numBytes += sVarf_init(&sVarf_iOPbRv3N, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pL7I6NWd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VX9qf3Qs, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_h0SKcYOd, "del-1446-flanger-r");
  numBytes += sVarf_init(&sVarf_h9QfJkcA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r8phHBBk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Dhx4tDb0, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_GB5nDq3m, 0.0f);
  numBytes += cDelay_init(this, &cDelay_0WYkkwaj, 0.0f);
  numBytes += hTable_init(&hTable_5mJknyI3, 256);
  numBytes += cDelay_init(this, &cDelay_5G2lgwua, 0.0f);
  numBytes += cDelay_init(this, &cDelay_bohiRGaj, 0.0f);
  numBytes += hTable_init(&hTable_exYt3KeQ, 256);
  numBytes += cVar_init_f(&cVar_Ps1iK0l3, 14.0f);
  numBytes += cBinop_init(&cBinop_lAmRqm1E, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_bhhvqNdD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_j42Uhmfq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_KtyTmzdw, 14.0f);
  numBytes += cBinop_init(&cBinop_EvcUTUT7, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_6uUX7HCw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WEMJuxTY, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_8FtXUwIV, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_5AEIh4XR, 1, -1);
  numBytes += cVar_init_f(&cVar_FgVn4JK2, 0.2f);
  numBytes += cSlice_init(&cSlice_vVJNKGYB, 1, -1);
  numBytes += cVar_init_f(&cVar_RBQ3tLw5, 0.0f);
  numBytes += cSlice_init(&cSlice_xTv4Qohj, 1, -1);
  numBytes += cVar_init_f(&cVar_5Cbo5sq9, 2.0f);
  numBytes += cSlice_init(&cSlice_gjlsqZ22, 1, -1);
  numBytes += cVar_init_f(&cVar_paaCci6I, 0.5f);
  numBytes += sVarf_init(&sVarf_6Z6VCamE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Fbq4FqgX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_A8fN3esW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dMWTBYqO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MQQVIybS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SannQb3C, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FL3NGR::~Heavy_WSTD_FL3NGR() {
  hTable_free(&hTable_0kXJuzoT);
  hTable_free(&hTable_0xQ7THyn);
  hTable_free(&hTable_fUllEQbq);
  hTable_free(&hTable_jPIHCBKs);
  hTable_free(&hTable_5mJknyI3);
  hTable_free(&hTable_exYt3KeQ);
}

HvTable *Heavy_WSTD_FL3NGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x7E84AE7C: return &hTable_0kXJuzoT; // del-1348-flanger-r
    case 0x8BC7EF65: return &hTable_0xQ7THyn; // del-1348-flanger-l
    case 0x67C454D4: return &hTable_fUllEQbq; // del-1397-flanger-r
    case 0x578173CB: return &hTable_jPIHCBKs; // del-1397-flanger-l
    case 0xB5F31EFF: return &hTable_5mJknyI3; // del-1446-flanger-r
    case 0xFB92DE56: return &hTable_exYt3KeQ; // del-1446-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FL3NGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0GxTb224_sendMessage);
      break;
    }
    case 0xACE44B9C: { // High_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yDC7WQzH_sendMessage);
      break;
    }
    case 0xA66E154B: { // High_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QhyDOSvK_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LW6UYRnp_sendMessage);
      break;
    }
    case 0x49068FB0: { // High_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kJe3oD2X_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qgrsReJt_sendMessage);
      break;
    }
    case 0xDDAB7A0: { // Low_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dhLnROco_sendMessage);
      break;
    }
    case 0xF8FE7D54: { // Low_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AiYOML0e_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A47uVLDJ_sendMessage);
      break;
    }
    case 0x768962E9: { // Low_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SHFPsb57_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HPYxLmtg_sendMessage);
      break;
    }
    case 0x9B44FA2D: { // Mid_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b2I8tzQo_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UJHt547h_sendMessage);
      break;
    }
    case 0x30AE5EFB: { // Mid_Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uAOZoOf0_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fjeifgMf_sendMessage);
      break;
    }
    case 0x78CC8F6D: { // Mid_Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w5UG4p23_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pgwg6mPR_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8WfXf7LH_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qKUEQ3J2_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lihC8wyZ_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c93YVyUX_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JlrFuOrO_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HI2ghAPE_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oy2Q0rcz_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cHHYr6yj_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_h9FXIWdX_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2KlNO53G_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_birnfPZ6_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NHXc6Znm_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1W7TuWy8_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zsqz5CAR_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vV12V56D_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6lLVK5kw_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0kt9qIFp_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SyjxstBe_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1VySlQuR_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wsJm63q5_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bYvFE1IU_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4Hp4Txwg_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mhf4fwkd_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_K0zSDMN2_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VQEAbYTP_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XrtVK6S3_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5jPPVl6q_sendMessage);
      break;
    }
    case 0xB9261D01: { // 1348-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1Ga11imP_sendMessage);
      break;
    }
    case 0x7B4AB7DC: { // 1348-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uvFMyu91_sendMessage);
      break;
    }
    case 0xC21D5730: { // 1348-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ETlfEQAF_sendMessage);
      break;
    }
    case 0x73E3A43F: { // 1348-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jK7MEz08_sendMessage);
      break;
    }
    case 0x8020E246: { // 1397-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t2V9UH2y_sendMessage);
      break;
    }
    case 0xDE6EF86C: { // 1397-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ue1wnmRI_sendMessage);
      break;
    }
    case 0x4C9CDCA8: { // 1397-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H8wKqsqv_sendMessage);
      break;
    }
    case 0xB69DF8D2: { // 1397-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nokKSX4g_sendMessage);
      break;
    }
    case 0x2ABB5D7C: { // 1446-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l66dHcd8_sendMessage);
      break;
    }
    case 0xE9A86FE0: { // 1446-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZfyA8EdR_sendMessage);
      break;
    }
    case 0xC66A3021: { // 1446-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qLPcCDlF_sendMessage);
      break;
    }
    case 0x64835C2: { // 1446-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iCDn2tAb_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GRn6k9uj_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FL3NGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Feedback";
        info->hash = 0xACE44B9C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "High_Intensity";
        info->hash = 0xA66E154B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 3: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 4: {
        info->name = "High_Speed";
        info->hash = 0x49068FB0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 5: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "Low_Feedback";
        info->hash = 0xDDAB7A0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 7: {
        info->name = "Low_Intensity";
        info->hash = 0xF8FE7D54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 8: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 9: {
        info->name = "Low_Speed";
        info->hash = 0x768962E9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 10: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "Mid_Feedback";
        info->hash = 0x9B44FA2D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 13: {
        info->name = "Mid_Intensity";
        info->hash = 0x30AE5EFB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 14: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 15: {
        info->name = "Mid_Speed";
        info->hash = 0x78CC8F6D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 16;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FL3NGR::cVar_uVpAyZE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cYuK85fD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_zkFL5DoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9TeTvhfW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_vCJCIC6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2aRVogqO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_Evw0V7ZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A7xlGZnn_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OhnEhMOS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_THFcR9Qp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RqGGyT21_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_YVxOnHGG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hwO4KKDE, 0, m, &cSlice_hwO4KKDE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g7EmU5Rq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_hwO4KKDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JDvheFK2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JDvheFK2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_3L4XG43Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JDvheFK2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_JDvheFK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qKUEQ3J2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_wMl3bmMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_glwJRKXW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_4YE5GxH6, 0, m, &cIf_4YE5GxH6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_4YE5GxH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_sfLC9MDi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_I39zfjGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_S4UrjiZj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_bvs7q9eQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_CrppIQki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_w0lGq554, HV_BINOP_POW, 0, m, &cBinop_w0lGq554_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_w0lGq554_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oG1hVGPR, 0, m, &cIf_oG1hVGPR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5XgNKcoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_SjnCYGW0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dIADOYwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I39zfjGh, 0, m, &cIf_I39zfjGh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sBptDI4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vvMHmGX4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_vvMHmGX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I39zfjGh, 1, m, &cIf_I39zfjGh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bvs7q9eQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_5XgNKcoT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_S4UrjiZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_oG1hVGPR, 0, m, &cIf_oG1hVGPR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SjnCYGW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w0lGq554, HV_BINOP_POW, 1, m, &cBinop_w0lGq554_sendMessage);
  cMsg_CrppIQki_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_oG1hVGPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_WPoutDy8, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_glwJRKXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4YE5GxH6, 1, m, &cIf_4YE5GxH6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_sfLC9MDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YKWyTbOT, HV_BINOP_GREATER_THAN, 1, m, &cBinop_YKWyTbOT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0C7fujE2, HV_BINOP_EQ, 1, m, &cBinop_0C7fujE2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_m4HNtVPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1Bnl6VT, HV_BINOP_ADD, 0, m, &cBinop_d1Bnl6VT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_d1Bnl6VT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sBptDI4y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dIADOYwJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YKWyTbOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oG1hVGPR, 1, m, &cIf_oG1hVGPR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0C7fujE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KKbPIv9h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_KKbPIv9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WPoutDy8, m);
}

void Heavy_WSTD_FL3NGR::cCast_1RQYLVfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d1Bnl6VT, HV_BINOP_ADD, 1, m, &cBinop_d1Bnl6VT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YKWyTbOT, HV_BINOP_GREATER_THAN, 0, m, &cBinop_YKWyTbOT_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0C7fujE2, HV_BINOP_EQ, 0, m, &cBinop_0C7fujE2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_yCwy3TuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wMl3bmMU, 0, m, &cVar_wMl3bmMU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hz17NUx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m4HNtVPv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_GDKgqdCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Z7sqi0hj_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ceXYQvfq, 0, m, &cIf_ceXYQvfq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ceXYQvfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_XRZyGAZ7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_yFCJY4Ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_qHDLT9xN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_IbufSto5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_0aGIqKpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DJwwkZkU, HV_BINOP_POW, 0, m, &cBinop_DJwwkZkU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DJwwkZkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ebslIM8B, 0, m, &cIf_ebslIM8B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_W1MGBYLZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pnZywXG5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_leLyVMX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yFCJY4Ck, 0, m, &cIf_yFCJY4Ck_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4HfdJ1px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_g02zYTf0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_g02zYTf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yFCJY4Ck, 1, m, &cIf_yFCJY4Ck_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IbufSto5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_W1MGBYLZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_qHDLT9xN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ebslIM8B, 0, m, &cIf_ebslIM8B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pnZywXG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DJwwkZkU, HV_BINOP_POW, 1, m, &cBinop_DJwwkZkU_sendMessage);
  cMsg_0aGIqKpv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_ebslIM8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dg1sqscs_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cdgAHtmB_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_KLzuhFJi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_Z7sqi0hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ceXYQvfq, 1, m, &cIf_ceXYQvfq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XRZyGAZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hrm4LiJH, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Hrm4LiJH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qm9UzVhZ, HV_BINOP_EQ, 1, m, &cBinop_Qm9UzVhZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mixMphDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYzgP1Gc, HV_BINOP_ADD, 0, m, &cBinop_UYzgP1Gc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UYzgP1Gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4HfdJ1px_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_leLyVMX3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Hrm4LiJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ebslIM8B, 1, m, &cIf_ebslIM8B_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Qm9UzVhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pzYb6JsR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_pzYb6JsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dg1sqscs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cdgAHtmB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_KLzuhFJi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fpQlCjwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UYzgP1Gc, HV_BINOP_ADD, 1, m, &cBinop_UYzgP1Gc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hrm4LiJH, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Hrm4LiJH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qm9UzVhZ, HV_BINOP_EQ, 0, m, &cBinop_Qm9UzVhZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0GVnQPGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GDKgqdCZ, 0, m, &cVar_GDKgqdCZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LSvtqxmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mixMphDH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_0yPe5rAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vEeW5sBh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ZfyvwuW9, 0, m, &cIf_ZfyvwuW9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ZfyvwuW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4p5GUHu6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_oK8AR1i3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_FKk4joMf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_P1odLNb1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_5eb8Y0pG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_M0JGxcpj, HV_BINOP_POW, 0, m, &cBinop_M0JGxcpj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_M0JGxcpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UnnOSgZB, 0, m, &cIf_UnnOSgZB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5Rd8w9Yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_nSu8MI69_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Qoa1VPYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oK8AR1i3, 0, m, &cIf_oK8AR1i3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Hvn3pE6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ieJdJ3UN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ieJdJ3UN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oK8AR1i3, 1, m, &cIf_oK8AR1i3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P1odLNb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_5Rd8w9Yl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FKk4joMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_UnnOSgZB, 0, m, &cIf_UnnOSgZB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nSu8MI69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M0JGxcpj, HV_BINOP_POW, 1, m, &cBinop_M0JGxcpj_sendMessage);
  cMsg_5eb8Y0pG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_UnnOSgZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_dovMLsnx, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_vEeW5sBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZfyvwuW9, 1, m, &cIf_ZfyvwuW9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4p5GUHu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZKPCiBB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DZKPCiBB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YCyHW7Av, HV_BINOP_EQ, 1, m, &cBinop_YCyHW7Av_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Pf4cBJRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VyRcGUhg, HV_BINOP_ADD, 0, m, &cBinop_VyRcGUhg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VyRcGUhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hvn3pE6k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qoa1VPYu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DZKPCiBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UnnOSgZB, 1, m, &cIf_UnnOSgZB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YCyHW7Av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_az3n0qw8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_az3n0qw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_dovMLsnx, m);
}

void Heavy_WSTD_FL3NGR::cCast_2bUCqo1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VyRcGUhg, HV_BINOP_ADD, 1, m, &cBinop_VyRcGUhg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZKPCiBB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DZKPCiBB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YCyHW7Av, HV_BINOP_EQ, 0, m, &cBinop_YCyHW7Av_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_imW0R7mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0yPe5rAz, 0, m, &cVar_0yPe5rAz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_oE9b7BRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pf4cBJRJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_3eL4ev8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_EvPReawm, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_xVwmYzDR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LiaSoMni, 0, m, &cSlice_LiaSoMni_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jhWlCtpD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_LiaSoMni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_76B6o1vc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_76B6o1vc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_6chdap7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_76B6o1vc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_76B6o1vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Pgwg6mPR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_jhWlCtpD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Z3w3KCcN, 0, m, &cSlice_Z3w3KCcN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YVxOnHGG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Z3w3KCcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XGNR3EJO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XGNR3EJO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_P6L3Kqte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XGNR3EJO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_XGNR3EJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_c93YVyUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_g7EmU5Rq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wgoEibuB, 0, m, &cSlice_wgoEibuB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gVyj5D4I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_wgoEibuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4vLBRUnX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4vLBRUnX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_YPfyIPsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4vLBRUnX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_4vLBRUnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8WfXf7LH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_gVyj5D4I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ia7lkMAs, 0, m, &cSlice_ia7lkMAs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ia7lkMAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wRf8Zq1g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wRf8Zq1g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_1qsej3pM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wRf8Zq1g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wRf8Zq1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lihC8wyZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_FBuTrutB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h9XYNFRf, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YHwzpmVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wBM5C2iq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_NjO8UKLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E10YTG2v, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_SoYAvgdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FP1y673P, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_zBTW5bYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HIYJ00HM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_noDZIIJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sApyIDDK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_sApyIDDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckFha73O, HV_BINOP_DIVIDE, 1, m, &cBinop_ckFha73O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vgAK5orz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_QtJXvuvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_buK8qjUY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_98POFPcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_QtJXvuvz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_buK8qjUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ckFha73O, HV_BINOP_DIVIDE, 0, m, &cBinop_ckFha73O_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_vgAK5orz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_98POFPcH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ckFha73O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KZVTNpp7, HV_BINOP_MULTIPLY, 1, m, &cBinop_KZVTNpp7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KZVTNpp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpBiTIEG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rWffRnSY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Xgxa8SI7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xlWJsxPa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_7G7JjFbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LZhQBZmz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SCLgEh0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_yxKPbLie_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yxKPbLie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KZVTNpp7, HV_BINOP_MULTIPLY, 0, m, &cBinop_KZVTNpp7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_b6PaBUSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_AGz9257l_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AGz9257l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HFsJAAp5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ABvS3Mcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uXujDCSY, 1, m, &cVar_uXujDCSY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_uXujDCSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EZQdFIWB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mskHcOHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rlGbCOPK, HV_BINOP_MULTIPLY, 1, m, &cBinop_rlGbCOPK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VTYSDQZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mskHcOHK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1DIrnjdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VkJ427f8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VkJ427f8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_niLrwmuy, HV_BINOP_MULTIPLY, 1, m, &cBinop_niLrwmuy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dT8WvhGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cnofYmYW, HV_BINOP_MULTIPLY, 1, m, &cBinop_cnofYmYW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Q9B4GpjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dT8WvhGz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EJiDhjXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lMLGqDGl, HV_BINOP_MULTIPLY, 1, m, &cBinop_lMLGqDGl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_renD3vcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OiP4DxKm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OiP4DxKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_snwYc2OZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_snwYc2OZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_fLEAIpyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r6BC4gal_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_SCLgEh0V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0hNh3XR9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_BiwQBcv3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_b6PaBUSX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rWffRnSY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_7G7JjFbP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QpBiTIEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Xgxa8SI7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_xlWJsxPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oy2Q0rcz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LZhQBZmz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HI2ghAPE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_vn0inxaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JlrFuOrO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_HFsJAAp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3zMSOQ65_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3zMSOQ65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Dsb2Fbs, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Dsb2Fbs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2Dsb2Fbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_F8465Hae_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F8465Hae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vn0inxaM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_EZQdFIWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Tqhaw3qo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Tqhaw3qo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pdA8PXUG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OVDHZTeN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E8J6T1sW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1irfLn0U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8w2XFL0m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oyWdkjSb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rlGbCOPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FBuTrutB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_niLrwmuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YHwzpmVg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cnofYmYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NjO8UKLA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lMLGqDGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SoYAvgdH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_snwYc2OZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zBTW5bYb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_VOeF28Py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fLEAIpyl, 0, m, &cVar_fLEAIpyl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_SHbxUqoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BiwQBcv3, 1, m, &cVar_BiwQBcv3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_8w2XFL0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_niLrwmuy, HV_BINOP_MULTIPLY, 0, m, &cBinop_niLrwmuy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OVDHZTeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_snwYc2OZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_snwYc2OZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_1irfLn0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cnofYmYW, HV_BINOP_MULTIPLY, 0, m, &cBinop_cnofYmYW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pdA8PXUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_oyWdkjSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rlGbCOPK, HV_BINOP_MULTIPLY, 0, m, &cBinop_rlGbCOPK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_E8J6T1sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lMLGqDGl, HV_BINOP_MULTIPLY, 0, m, &cBinop_lMLGqDGl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0hNh3XR9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uXujDCSY, 0, m, &cVar_uXujDCSY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_r6BC4gal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BiwQBcv3, 0, m, &cVar_BiwQBcv3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_6L9MJnus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fUcCzQbt, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_RvqaINft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gtqpY1Mq, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_6Jjxfdfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k8b47TYc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_v2L5LJpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_624nJyVR, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_W3ZGrbIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2pxwhTAF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_2pxwhTAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RqNtR5Mn, HV_BINOP_DIVIDE, 1, m, &cBinop_RqNtR5Mn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XpHXd82v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_yCTFqdxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_aPFEanws_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_0q0v25PP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_yCTFqdxN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_aPFEanws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RqNtR5Mn, HV_BINOP_DIVIDE, 0, m, &cBinop_RqNtR5Mn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XpHXd82v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0q0v25PP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_RqNtR5Mn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OAcDKekE, HV_BINOP_MULTIPLY, 1, m, &cBinop_OAcDKekE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OAcDKekE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VXk8dNSv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2rcfAvD4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_caGIR6M3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bADB16oL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_LdnV2ahx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3ahpUJVZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_m22biAJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Lx1tpT7K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lx1tpT7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OAcDKekE, HV_BINOP_MULTIPLY, 0, m, &cBinop_OAcDKekE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DKLCETv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_p6LKoNWS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_p6LKoNWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OzUN0Ft0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_W0wQ6mj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oq2ktibC, HV_BINOP_MULTIPLY, 1, m, &cBinop_Oq2ktibC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2jnZaWXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E2INXboP, 1, m, &cVar_E2INXboP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nVN2SG4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pCs9T8NP, HV_BINOP_MULTIPLY, 1, m, &cBinop_pCs9T8NP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OpuvSkVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bjfluqS2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bjfluqS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gOzHpV1e, HV_BINOP_MULTIPLY, 1, m, &cBinop_gOzHpV1e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_E2INXboP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X11rbTZA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_wg7Jbenc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sVj8m8b7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_m22biAJT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hwHWnswG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_2fm6PhxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DKLCETv4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2rcfAvD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_LdnV2ahx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_VXk8dNSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_caGIR6M3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_bADB16oL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2KlNO53G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_3ahpUJVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_h9FXIWdX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Sf2jEE3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cHHYr6yj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_OzUN0Ft0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Kytd0IwA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Kytd0IwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ss9NsmPM, HV_BINOP_MULTIPLY, 1, m, &cBinop_ss9NsmPM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ss9NsmPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2OxI9TRJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_2OxI9TRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Sf2jEE3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_X11rbTZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Gm2vlLfc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Gm2vlLfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W6n33WfN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LXUtKuvO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Vn0EMIFh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CqbdXMeS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jxyy9AKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6L9MJnus_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Oq2ktibC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RvqaINft_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pCs9T8NP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6Jjxfdfg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gOzHpV1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v2L5LJpp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_5efE1rX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wg7Jbenc, 0, m, &cVar_wg7Jbenc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_mEgSHdih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2fm6PhxA, 1, m, &cVar_2fm6PhxA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hwHWnswG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E2INXboP, 0, m, &cVar_E2INXboP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sVj8m8b7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2fm6PhxA, 0, m, &cVar_2fm6PhxA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_CqbdXMeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jxyy9AKr, HV_BINOP_MULTIPLY, 0, m, &cBinop_jxyy9AKr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_W6n33WfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gOzHpV1e, HV_BINOP_MULTIPLY, 0, m, &cBinop_gOzHpV1e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Vn0EMIFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Oq2ktibC, HV_BINOP_MULTIPLY, 0, m, &cBinop_Oq2ktibC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_LXUtKuvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pCs9T8NP, HV_BINOP_MULTIPLY, 0, m, &cBinop_pCs9T8NP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_vqLrAbG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TmqnO8TC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hnXF98zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dDME5tZl, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_EhXKcJFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_17mxWgEB, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_812nX2fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hXN8FsA3, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_J5M7vUxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_59pETihH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hHctbQCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_udxGJjvx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_udxGJjvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vDj6jCaF, HV_BINOP_DIVIDE, 1, m, &cBinop_vDj6jCaF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fYOwQfJT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_pLVKXtZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_s7tqt9mN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_FsBN1hca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_pLVKXtZB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_s7tqt9mN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vDj6jCaF, HV_BINOP_DIVIDE, 0, m, &cBinop_vDj6jCaF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fYOwQfJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FsBN1hca_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vDj6jCaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XpowOCxq, HV_BINOP_MULTIPLY, 1, m, &cBinop_XpowOCxq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XpowOCxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V6FDTAna_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HKH6mYNh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_sqNB4WDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8btMFApe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_M96vfemh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bGyHu5GM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_ORzb45y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_c82st5f4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c82st5f4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XpowOCxq, HV_BINOP_MULTIPLY, 0, m, &cBinop_XpowOCxq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fplZWhXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_7Ke3u6Ru_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7Ke3u6Ru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aM4rWLra_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xt313l5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NyyYyjRY, HV_BINOP_MULTIPLY, 1, m, &cBinop_NyyYyjRY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3r0YNVFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_mo5vyveo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mo5vyveo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xt313l5m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_SgChnnLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ukjGp3VK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ukjGp3VK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E2pTrHgO, HV_BINOP_MULTIPLY, 1, m, &cBinop_E2pTrHgO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PcBc6WUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SfYwkApE, HV_BINOP_MULTIPLY, 1, m, &cBinop_SfYwkApE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VkETzEk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ePKCQZte_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ePKCQZte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PcBc6WUQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fzn1yNgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dfXAb5j1, 1, m, &cVar_dfXAb5j1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MLbNotrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6OemIwhR, HV_BINOP_MULTIPLY, 1, m, &cBinop_6OemIwhR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PHhSZYAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Oi2QQEWD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Oi2QQEWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_auw5EaDm, HV_BINOP_MULTIPLY, 1, m, &cBinop_auw5EaDm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_dfXAb5j1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X74jpeSN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_HYlG5tgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NZNvQfJH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ORzb45y7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OpxpsOWQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_whRFX1VF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_fplZWhXc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HKH6mYNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_M96vfemh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_V6FDTAna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_sqNB4WDl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_8btMFApe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1W7TuWy8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_bGyHu5GM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NHXc6Znm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_UtgHGaPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_birnfPZ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_aM4rWLra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dypSkB5e_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dypSkB5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m0QIbzbE, HV_BINOP_MULTIPLY, 1, m, &cBinop_m0QIbzbE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m0QIbzbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RiOpEjXU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RiOpEjXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UtgHGaPe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_X74jpeSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Wcp8uaGK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Wcp8uaGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jqv4UkiE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HjIuonYS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3JFVvrU8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4CTtDD56_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uIH6ZPde_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dFVIKGZD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NyyYyjRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vqLrAbG2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_E2pTrHgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hnXF98zq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SfYwkApE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EhXKcJFj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_6OemIwhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_812nX2fw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_auw5EaDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J5M7vUxo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_1s2P6bnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HYlG5tgN, 0, m, &cVar_HYlG5tgN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7WqISkzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_whRFX1VF, 1, m, &cVar_whRFX1VF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_uIH6ZPde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E2pTrHgO, HV_BINOP_MULTIPLY, 0, m, &cBinop_E2pTrHgO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HjIuonYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_auw5EaDm, HV_BINOP_MULTIPLY, 0, m, &cBinop_auw5EaDm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4CTtDD56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SfYwkApE, HV_BINOP_MULTIPLY, 0, m, &cBinop_SfYwkApE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Jqv4UkiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_dFVIKGZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NyyYyjRY, HV_BINOP_MULTIPLY, 0, m, &cBinop_NyyYyjRY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3JFVvrU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6OemIwhR, HV_BINOP_MULTIPLY, 0, m, &cBinop_6OemIwhR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OpxpsOWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dfXAb5j1, 0, m, &cVar_dfXAb5j1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NZNvQfJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_whRFX1VF, 0, m, &cVar_whRFX1VF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dg1sqscs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3eL4ev8S, 1, m, &cIf_3eL4ev8S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_52Kde2qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EvPReawm, m);
}

void Heavy_WSTD_FL3NGR::cBinop_cdgAHtmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_52Kde2qg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KLzuhFJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3eL4ev8S, 0, m, &cIf_3eL4ev8S_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_1u4xYghr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2hmXqYra, 0, m, &cSlice_2hmXqYra_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bjhNhjpK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_2hmXqYra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Djz30j0x_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Djz30j0x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_d4KYBiIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Djz30j0x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_Djz30j0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6lLVK5kw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_8ihbOjID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HhuW1Nq6_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_e3RX29gX, 0, m, &cIf_e3RX29gX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_e3RX29gX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CofUZTcs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_3ImbbNQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_KnPLpGXf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_QmX5PekT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_nHEfkzVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_neNz1HJN, HV_BINOP_POW, 0, m, &cBinop_neNz1HJN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_neNz1HJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E68Ud8pC, 0, m, &cIf_E68Ud8pC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UQ92QLXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xafg5CUA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_3tWepF7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3ImbbNQw, 0, m, &cIf_3ImbbNQw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_AnNEl4sG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_7nCCJCOx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7nCCJCOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3ImbbNQw, 1, m, &cIf_3ImbbNQw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_QmX5PekT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_UQ92QLXp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KnPLpGXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_E68Ud8pC, 0, m, &cIf_E68Ud8pC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xafg5CUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_neNz1HJN, HV_BINOP_POW, 1, m, &cBinop_neNz1HJN_sendMessage);
  cMsg_nHEfkzVF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_E68Ud8pC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_zazBS8NY, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_HhuW1Nq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e3RX29gX, 1, m, &cIf_e3RX29gX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CofUZTcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rhAH4f88, HV_BINOP_GREATER_THAN, 1, m, &cBinop_rhAH4f88_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EUccXcVW, HV_BINOP_EQ, 1, m, &cBinop_EUccXcVW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_zySDJ9tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_00Fbllj5, HV_BINOP_ADD, 0, m, &cBinop_00Fbllj5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_00Fbllj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AnNEl4sG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3tWepF7g_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rhAH4f88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E68Ud8pC, 1, m, &cIf_E68Ud8pC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EUccXcVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vuAGpLJz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_vuAGpLJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_zazBS8NY, m);
}

void Heavy_WSTD_FL3NGR::cCast_O5awPh5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_00Fbllj5, HV_BINOP_ADD, 1, m, &cBinop_00Fbllj5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rhAH4f88, HV_BINOP_GREATER_THAN, 0, m, &cBinop_rhAH4f88_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EUccXcVW, HV_BINOP_EQ, 0, m, &cBinop_EUccXcVW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ULcd8pri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8ihbOjID, 0, m, &cVar_8ihbOjID_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_k2ibUfZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zySDJ9tz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_7fAfAH0s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5KZbPg3y_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ss4xqlBX, 0, m, &cIf_ss4xqlBX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_ss4xqlBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_CxWV3ZFt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_vKzHaBkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mhC5I2QQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_xf6eRgTp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_hrQX0Xo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GlMWqLHU, HV_BINOP_POW, 0, m, &cBinop_GlMWqLHU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_GlMWqLHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_59GMCRiF, 0, m, &cIf_59GMCRiF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ifXpnIIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_XCgzvsxW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_A03zYxtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_gOz6E67I_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZFtGVaN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vKzHaBkr, 0, m, &cIf_vKzHaBkr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gOz6E67I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vKzHaBkr, 1, m, &cIf_vKzHaBkr_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xf6eRgTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ifXpnIIk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_mhC5I2QQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_59GMCRiF, 0, m, &cIf_59GMCRiF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XCgzvsxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GlMWqLHU, HV_BINOP_POW, 1, m, &cBinop_GlMWqLHU_sendMessage);
  cMsg_hrQX0Xo7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_59GMCRiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KEB9RHY0_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Muwq8bdV_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_HYtYEmRv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_5KZbPg3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ss4xqlBX, 1, m, &cIf_ss4xqlBX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CxWV3ZFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVOcC9ki, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bVOcC9ki_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cg2c8BvI, HV_BINOP_EQ, 1, m, &cBinop_cg2c8BvI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_etv14S4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_uxcevUeP, HV_BINOP_ADD, 0, m, &cBinop_uxcevUeP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uxcevUeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A03zYxtu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZFtGVaN4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bVOcC9ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_59GMCRiF, 1, m, &cIf_59GMCRiF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cg2c8BvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EHfmw41J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_EHfmw41J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KEB9RHY0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Muwq8bdV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_HYtYEmRv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_J6C9t2vL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_etv14S4x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_785GyDob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uxcevUeP, HV_BINOP_ADD, 1, m, &cBinop_uxcevUeP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bVOcC9ki, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bVOcC9ki_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_cg2c8BvI, HV_BINOP_EQ, 0, m, &cBinop_cg2c8BvI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_5xPwYhok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7fAfAH0s, 0, m, &cVar_7fAfAH0s_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_7Taz0BLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VS52oF9j_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_dW2wAcK8, 0, m, &cIf_dW2wAcK8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_dW2wAcK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xTdvTaKG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cIf_14VIHDVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_PCIrbToL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mLwF7C97_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cMsg_vJ6GoyIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HSLOCPy4, HV_BINOP_POW, 0, m, &cBinop_HSLOCPy4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HSLOCPy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bt8UhCdc, 0, m, &cIf_bt8UhCdc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qUgeS9yk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_MMefNBf8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sCoo5NYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_V1bSsGdO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_e9OnTooK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_14VIHDVY, 0, m, &cIf_14VIHDVY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V1bSsGdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_14VIHDVY, 1, m, &cIf_14VIHDVY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_mLwF7C97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_qUgeS9yk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_PCIrbToL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_bt8UhCdc, 0, m, &cIf_bt8UhCdc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_MMefNBf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HSLOCPy4, HV_BINOP_POW, 1, m, &cBinop_HSLOCPy4_sendMessage);
  cMsg_vJ6GoyIt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cIf_bt8UhCdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_0VR2a120, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cBinop_VS52oF9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dW2wAcK8, 1, m, &cIf_dW2wAcK8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_xTdvTaKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCKil0io, HV_BINOP_GREATER_THAN, 1, m, &cBinop_DCKil0io_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IkyDfFq0, HV_BINOP_EQ, 1, m, &cBinop_IkyDfFq0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_kH12G67b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zSdNYO5K, HV_BINOP_ADD, 0, m, &cBinop_zSdNYO5K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zSdNYO5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sCoo5NYf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e9OnTooK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_DCKil0io_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bt8UhCdc, 1, m, &cIf_bt8UhCdc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_IkyDfFq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BgaV9sKQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_BgaV9sKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0VR2a120, m);
}

void Heavy_WSTD_FL3NGR::cCast_Au7qtCgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7Taz0BLy, 0, m, &cVar_7Taz0BLy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sitpRwH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kH12G67b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_fpYrZVeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zSdNYO5K, HV_BINOP_ADD, 1, m, &cBinop_zSdNYO5K_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DCKil0io, HV_BINOP_GREATER_THAN, 0, m, &cBinop_DCKil0io_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IkyDfFq0, HV_BINOP_EQ, 0, m, &cBinop_IkyDfFq0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cIf_AfsVxvqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_7jecEgCm, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cSwitchcase_By4EXSBZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rwRUTak1, 0, m, &cSlice_rwRUTak1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CUkDL8XT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_rwRUTak1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5qhuuC6o_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5qhuuC6o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_QBHJCxBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5qhuuC6o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_5qhuuC6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zsqz5CAR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_CUkDL8XT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mQQ6bIzu, 0, m, &cSlice_mQQ6bIzu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1u4xYghr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_mQQ6bIzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wSGqSDoE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wSGqSDoE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_kei45EjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wSGqSDoE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_wSGqSDoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SyjxstBe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_bjhNhjpK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_66yr5t2M, 0, m, &cSlice_66yr5t2M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zUxZAkhU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_66yr5t2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_D00rtvly_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_D00rtvly_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_ZeIMwCRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_D00rtvly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_D00rtvly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vV12V56D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_zUxZAkhU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_58fTYBs1, 0, m, &cSlice_58fTYBs1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_58fTYBs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LyzdLjMC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LyzdLjMC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_0g5of0Na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LyzdLjMC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LyzdLjMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0kt9qIFp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VlW2Iahc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Aktkxcce, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_C8kxpmIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3mHnlXnM, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0Fmo0I3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P91c108O, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sLFLK0PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gikfnGzI, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QXz41OmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iTgM2ijW, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_FDBchqbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nwFwIo6d_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_nwFwIo6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0lnRGjuJ, HV_BINOP_DIVIDE, 1, m, &cBinop_0lnRGjuJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DoedkJJV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Dsk4Jcqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_puFENg0G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_24vjhbds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Dsk4Jcqs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_puFENg0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0lnRGjuJ, HV_BINOP_DIVIDE, 0, m, &cBinop_0lnRGjuJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_DoedkJJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_24vjhbds_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0lnRGjuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J6oXymrG, HV_BINOP_MULTIPLY, 1, m, &cBinop_J6oXymrG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J6oXymrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HwobKPRd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0Vm0nxxw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_x5kmyQdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UEqd9an5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_0AX06f73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_POOBsIHn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nsMNN4h1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_m43NCUXO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_m43NCUXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J6oXymrG, HV_BINOP_MULTIPLY, 0, m, &cBinop_J6oXymrG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_c5DwtBbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_dT6f7ZpI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_dT6f7ZpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wM1qbO6H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TTbknGb7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WqpWGzwj, 1, m, &cVar_WqpWGzwj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_WqpWGzwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jFf1f7o3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EQA3Bm0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S9W76vT7, HV_BINOP_MULTIPLY, 1, m, &cBinop_S9W76vT7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4gqMnCst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EQA3Bm0w_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ns3cxIlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kIgNd1l8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_kIgNd1l8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KjAiwxzu, HV_BINOP_MULTIPLY, 1, m, &cBinop_KjAiwxzu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8B4X3lG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SguOs05E, HV_BINOP_MULTIPLY, 1, m, &cBinop_SguOs05E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YU1Yu0Ht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8B4X3lG6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_f2uOaqYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_voEyL3If, HV_BINOP_MULTIPLY, 1, m, &cBinop_voEyL3If_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_ThwSu5Cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_P8cF4vl4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_P8cF4vl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I5h43v7P, HV_BINOP_MULTIPLY, 1, m, &cBinop_I5h43v7P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_8kVmapEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4dltYG7S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_nsMNN4h1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UWKnhoIn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_XPvewAJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_c5DwtBbn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_HwobKPRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_x5kmyQdk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0Vm0nxxw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0AX06f73_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_UEqd9an5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bYvFE1IU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_POOBsIHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wsJm63q5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_bMmu17SD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1VySlQuR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wM1qbO6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BtuelYet_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BtuelYet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XU4G9YZ9, HV_BINOP_MULTIPLY, 1, m, &cBinop_XU4G9YZ9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XU4G9YZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_A4FWTrFm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A4FWTrFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bMmu17SD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_jFf1f7o3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Foo7B3bC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Foo7B3bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PP3YDXrF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bAsZvRyr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a2xvzfBX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K7eh4BYv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_snzXtNby_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8DY1Ezvl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_S9W76vT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VlW2Iahc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KjAiwxzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C8kxpmIg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SguOs05E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Fmo0I3C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_voEyL3If_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sLFLK0PD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_I5h43v7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QXz41OmN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_cjuF7usW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XPvewAJg, 1, m, &cVar_XPvewAJg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2HAAmkFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8kVmapEU, 0, m, &cVar_8kVmapEU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_snzXtNby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KjAiwxzu, HV_BINOP_MULTIPLY, 0, m, &cBinop_KjAiwxzu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_bAsZvRyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I5h43v7P, HV_BINOP_MULTIPLY, 0, m, &cBinop_I5h43v7P_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_K7eh4BYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SguOs05E, HV_BINOP_MULTIPLY, 0, m, &cBinop_SguOs05E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PP3YDXrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_8DY1Ezvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S9W76vT7, HV_BINOP_MULTIPLY, 0, m, &cBinop_S9W76vT7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_a2xvzfBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_voEyL3If, HV_BINOP_MULTIPLY, 0, m, &cBinop_voEyL3If_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_UWKnhoIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WqpWGzwj, 0, m, &cVar_WqpWGzwj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_4dltYG7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XPvewAJg, 0, m, &cVar_XPvewAJg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_sexZX3ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EJoJnBJt, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_vcPPQfyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lPsLHcxU, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Jj2PiWDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9z8jmUoA, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_r8VQhkck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DaCKeQfS, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eVhOODDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FKCuLamp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_FKCuLamp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NtBPcwFV, HV_BINOP_DIVIDE, 1, m, &cBinop_NtBPcwFV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hzzlrtxL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_Opxu5tA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KMi5BQwf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_GElpElmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Opxu5tA1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KMi5BQwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NtBPcwFV, HV_BINOP_DIVIDE, 0, m, &cBinop_NtBPcwFV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_hzzlrtxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GElpElmm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_NtBPcwFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lbfx67nI, HV_BINOP_MULTIPLY, 1, m, &cBinop_Lbfx67nI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lbfx67nI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dRBvcXnW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tq9R6tP8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_fbUT5WPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RtqA9zKD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_R1FnzD7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mMORLGl6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_rSKWzUa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Sv7nBFED_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Sv7nBFED_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Lbfx67nI, HV_BINOP_MULTIPLY, 0, m, &cBinop_Lbfx67nI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SFaXZgHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_yI4dPsJl_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yI4dPsJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I2hwEBjJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_nOWrrhpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2nNekXev, HV_BINOP_MULTIPLY, 1, m, &cBinop_2nNekXev_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jMLbcf4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hUKFhVCF, 1, m, &cVar_hUKFhVCF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tlDwY3Rs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K5ZD4qH4, HV_BINOP_MULTIPLY, 1, m, &cBinop_K5ZD4qH4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_yCDUmhTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9O2fu39G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9O2fu39G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xdvsp9wY, HV_BINOP_MULTIPLY, 1, m, &cBinop_Xdvsp9wY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_hUKFhVCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d2YWbEhw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_ViQzFV0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P6X11xkB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_rSKWzUa7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nvOc45LN_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_3V5BzbEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SFaXZgHb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Tq9R6tP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_R1FnzD7Q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_dRBvcXnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_fbUT5WPb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_RtqA9zKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_K0zSDMN2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_mMORLGl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Mhf4fwkd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_tipfsrWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4Hp4Txwg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_I2hwEBjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_B9n5Uo8G_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_B9n5Uo8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Z2kHeBM, HV_BINOP_MULTIPLY, 1, m, &cBinop_5Z2kHeBM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_5Z2kHeBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8BqbByfp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8BqbByfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tipfsrWb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_d2YWbEhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AuSK6JCV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AuSK6JCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0ApPm9mG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PK0AfB20_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NJ48DNP2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m2cXtTOH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HMAf7Q0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sexZX3ur_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2nNekXev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vcPPQfyu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_K5ZD4qH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jj2PiWDN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Xdvsp9wY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r8VQhkck_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_GZM0gAdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3V5BzbEx, 1, m, &cVar_3V5BzbEx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7ra6cWvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ViQzFV0J, 0, m, &cVar_ViQzFV0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_P6X11xkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3V5BzbEx, 0, m, &cVar_3V5BzbEx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_nvOc45LN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hUKFhVCF, 0, m, &cVar_hUKFhVCF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_m2cXtTOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HMAf7Q0m, HV_BINOP_MULTIPLY, 0, m, &cBinop_HMAf7Q0m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0ApPm9mG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Xdvsp9wY, HV_BINOP_MULTIPLY, 0, m, &cBinop_Xdvsp9wY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_NJ48DNP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2nNekXev, HV_BINOP_MULTIPLY, 0, m, &cBinop_2nNekXev_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_PK0AfB20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K5ZD4qH4, HV_BINOP_MULTIPLY, 0, m, &cBinop_K5ZD4qH4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_9pND09nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ALBNZ6Ug, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_gwpgPqHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Rw3MiDJA, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_JqwnXgsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PDUR6Oga, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MJT4hNx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aFHpFC2I, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_YQht7awq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DBepuiNk, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_rr20vKzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SVed343N_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_SVed343N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pE8LqVnw, HV_BINOP_DIVIDE, 1, m, &cBinop_pE8LqVnw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TwLaT4RL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_PNdX6Fy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_nwYu1VvW_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_q8FX3aUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_PNdX6Fy5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nwYu1VvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pE8LqVnw, HV_BINOP_DIVIDE, 0, m, &cBinop_pE8LqVnw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_TwLaT4RL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_q8FX3aUc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_pE8LqVnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gsG594lo, HV_BINOP_MULTIPLY, 1, m, &cBinop_gsG594lo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gsG594lo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ttCJnBhG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aKrzsKxi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_TZ6exdmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wv8jmqF0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_WZwnKUBh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YBX0oF2a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_gqux3ctn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Kt9BUgwR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Kt9BUgwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gsG594lo, HV_BINOP_MULTIPLY, 0, m, &cBinop_gsG594lo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9nmdTfks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_F4c8xHEe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_F4c8xHEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g2LsgI8x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_4rjIddop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HqzeAWzq, HV_BINOP_MULTIPLY, 1, m, &cBinop_HqzeAWzq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_pYTUzail_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WuRHTvnB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WuRHTvnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4rjIddop_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_BTZ0VgKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AGJ9iQoe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_AGJ9iQoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b3cjboZy, HV_BINOP_MULTIPLY, 1, m, &cBinop_b3cjboZy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_RqdNAlAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IE3ELBxV, HV_BINOP_MULTIPLY, 1, m, &cBinop_IE3ELBxV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nrYvd3Af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9epDt5WA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9epDt5WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RqdNAlAH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_3yz4HznV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_puXDRBaL, 1, m, &cVar_puXDRBaL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gvlg88xJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qw1A3BQ2, HV_BINOP_MULTIPLY, 1, m, &cBinop_qw1A3BQ2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Y5nkWHlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_J6CWjGWq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_J6CWjGWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SrcYyrCR, HV_BINOP_MULTIPLY, 1, m, &cBinop_SrcYyrCR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_puXDRBaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eqLrirFs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_P1l6h1vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zZh7sOte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_gqux3ctn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZFMV3Jsb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_qEAn7wh9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9nmdTfks_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ttCJnBhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_TZ6exdmV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_aKrzsKxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_WZwnKUBh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSend_wv8jmqF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5jPPVl6q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_YBX0oF2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XrtVK6S3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_3J6cXJJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VQEAbYTP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_g2LsgI8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uVQqZHIo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uVQqZHIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PMlh3FMJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_PMlh3FMJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_PMlh3FMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9asSPuMy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9asSPuMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3J6cXJJD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_eqLrirFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bHAsKBDk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bHAsKBDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pTiTIgj3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a0dD9Vf4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MoUPprO4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_drOQ3CzI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sLO2Z1a3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CazVAxVo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_HqzeAWzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9pND09nx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_b3cjboZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gwpgPqHm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_IE3ELBxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JqwnXgsk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qw1A3BQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MJT4hNx6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SrcYyrCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YQht7awq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cCast_RHGoYag2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P1l6h1vb, 0, m, &cVar_P1l6h1vb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_XYilX8bV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qEAn7wh9, 1, m, &cVar_qEAn7wh9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_sLO2Z1a3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b3cjboZy, HV_BINOP_MULTIPLY, 0, m, &cBinop_b3cjboZy_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_a0dD9Vf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SrcYyrCR, HV_BINOP_MULTIPLY, 0, m, &cBinop_SrcYyrCR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_drOQ3CzI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IE3ELBxV, HV_BINOP_MULTIPLY, 0, m, &cBinop_IE3ELBxV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_pTiTIgj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_FL3NGR::cCast_CazVAxVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HqzeAWzq, HV_BINOP_MULTIPLY, 0, m, &cBinop_HqzeAWzq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_MoUPprO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qw1A3BQ2, HV_BINOP_MULTIPLY, 0, m, &cBinop_qw1A3BQ2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ZFMV3Jsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_puXDRBaL, 0, m, &cVar_puXDRBaL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_zZh7sOte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qEAn7wh9, 0, m, &cVar_qEAn7wh9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_KEB9RHY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AfsVxvqF, 1, m, &cIf_AfsVxvqF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_arnLNZIx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7jecEgCm, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Muwq8bdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_arnLNZIx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_HYtYEmRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AfsVxvqF, 0, m, &cIf_AfsVxvqF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_8PBIqvX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7q0dFfss, HV_BINOP_DIVIDE, 0, m, &cBinop_7q0dFfss_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_ggbiZbu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rz72PXez, HV_BINOP_DIVIDE, 1, m, &cBinop_Rz72PXez_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7q0dFfss, HV_BINOP_DIVIDE, 1, m, &cBinop_7q0dFfss_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_zjvanY5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WCCfq3ci, HV_BINOP_DIVIDE, 0, m, &cBinop_WCCfq3ci_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_3YAknTwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WCCfq3ci, HV_BINOP_DIVIDE, 1, m, &cBinop_WCCfq3ci_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_THFcR9Qp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8PBIqvX8, 0, m, &cVar_8PBIqvX8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_OhnEhMOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ggbiZbu1, 0, m, &cVar_ggbiZbu1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_RqGGyT21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rz72PXez, HV_BINOP_DIVIDE, 0, m, &cBinop_Rz72PXez_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Rz72PXez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_zjvanY5D_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7q0dFfss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_3YAknTwP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WCCfq3ci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_0gLEuxfK_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_EXlL0FJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_jjZMHNkO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YrTn4CtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_k6xL4STa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0gLEuxfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YrTn4CtP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_k6xL4STa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_EXlL0FJR_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jjZMHNkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0CRMu3op_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_P1qC9Njg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_snxCpzBM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_GBb4yB8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_930Zz87L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_sp3YIHOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MnNhWrTZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_TbHSNimL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_daeH7N23_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_QMuCi2lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8gLoq7lQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_zQNoWIc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OQ4rk5Rj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_2MCnAFpo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QOUxifJi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_xYo12C79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VZjCI4TN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_jRp1SfMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PTZX5AJg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_h6F9cas4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sKchadZq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_wIC8CdJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jOJQ8WEE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cVar_GieRInnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OGrpmK5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TSav43td_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_r5hWR2s0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_r5hWR2s0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_Esxz9yMm, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_texMxWsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X2EJalG4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_X2EJalG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_0ddBYKAC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_91G1z4Rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VVPsBPeP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_evRfHvMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XEVjzGAy_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wpfW3PB5, m);
}

void Heavy_WSTD_FL3NGR::cBinop_0ddBYKAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uDfhR1dW, m);
}

void Heavy_WSTD_FL3NGR::cMsg_VVPsBPeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_evRfHvMo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_XEVjzGAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VApOf2eL, m);
}

void Heavy_WSTD_FL3NGR::cMsg_MY9yTgcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Mvj8ORGF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Mvj8ORGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_x8SO9PeC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_aZMGsB6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PqVijAjl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_N8FNWUSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_YqLMn3i5_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_oojM5twO, m);
}

void Heavy_WSTD_FL3NGR::cBinop_x8SO9PeC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_RF5cQhEN, m);
}

void Heavy_WSTD_FL3NGR::cMsg_PqVijAjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_N8FNWUSg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YqLMn3i5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_15Y4tSEc, m);
}

void Heavy_WSTD_FL3NGR::cBinop_mjz3kPfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4dCNPl9o_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4dCNPl9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_bhplKjr9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_qpodncph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HGujQv59_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_g4JzvVJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jHkCXgOK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_bhplKjr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UmrNzTMZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_UmrNzTMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_axaQ8xC4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T9PvtZFk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_axaQ8xC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TanDmQYp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T9PvtZFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3tjIXZnj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_TanDmQYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cIcAmn3C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3tjIXZnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rVilb6VY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rVilb6VY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bWnnZIbL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cIcAmn3C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_qpodncph_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bWnnZIbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_g4JzvVJ6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_N6RWrVf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_INy2LeDc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_INy2LeDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LGRIOEPw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_dsAZGdZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_quJVzHJ6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_quJVzHJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_E1MgxhJU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_B6EciDim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B6EciDim, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sc5t7f50, 0, m, &cDelay_Sc5t7f50_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B6EciDim, 0, m, &cDelay_B6EciDim_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LRwvX4DO, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_Sc5t7f50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Sc5t7f50, m);
  cMsg_Rjz3a2nD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_CeHj5n5F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wMsWNs3b_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_ciO882WD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vg85V0AJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_0kXJuzoT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eHwip0IQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_B6EciDim, 2, m, &cDelay_B6EciDim_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lYEeZt1T_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Vg85V0AJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0kXJuzoT, 0, m, &hTable_0kXJuzoT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_E1MgxhJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_ciO882WD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Rjz3a2nD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0kXJuzoT, 0, m, &hTable_0kXJuzoT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_lYEeZt1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B6EciDim, 0, m, &cDelay_B6EciDim_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_eHwip0IQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sc5t7f50, 2, m, &cDelay_Sc5t7f50_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wMsWNs3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_LRwvX4DO, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_eOjDN6Aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0hN8TeO7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_0hN8TeO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_gF4GseZ9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_WKdj8aDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WKdj8aDf, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_znabT3nG, 0, m, &cDelay_znabT3nG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WKdj8aDf, 0, m, &cDelay_WKdj8aDf_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4n3fj4yb, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_znabT3nG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_znabT3nG, m);
  cMsg_J3ILDuJy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_UVevhKrd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_V1gXn1GM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_MQ8qHBJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XEmpLFrF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_0xQ7THyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g9Nj5IfZ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_WKdj8aDf, 2, m, &cDelay_WKdj8aDf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Iwy1MfC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XEmpLFrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0xQ7THyn, 0, m, &hTable_0xQ7THyn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_gF4GseZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_MQ8qHBJC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_J3ILDuJy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0xQ7THyn, 0, m, &hTable_0xQ7THyn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0Iwy1MfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WKdj8aDf, 0, m, &cDelay_WKdj8aDf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_g9Nj5IfZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_znabT3nG, 2, m, &cDelay_znabT3nG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_V1gXn1GM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4n3fj4yb, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_uPUsXlgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_opK1bIcw, HV_BINOP_MULTIPLY, 0, m, &cBinop_opK1bIcw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_jqFfaVtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Wdvhk65X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Wdvhk65X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wnH3t8B7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_opK1bIcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_jMfNQKXQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_OfrLKj7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_opK1bIcw, HV_BINOP_MULTIPLY, 1, m, &cBinop_opK1bIcw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_wnH3t8B7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OfrLKj7a_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_jMfNQKXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Dye5BfVC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Dye5BfVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uD9oQ1w8_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1KFBptOr, m);
}

void Heavy_WSTD_FL3NGR::cBinop_uD9oQ1w8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vTkzWq5v, m);
}

void Heavy_WSTD_FL3NGR::cVar_CVqxGADU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eOLR9Ffz, HV_BINOP_MULTIPLY, 0, m, &cBinop_eOLR9Ffz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_4XJD27cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_eEmDWYPg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_eEmDWYPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3X0PVquk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_eOLR9Ffz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0DB2KpeE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_1leOqzwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eOLR9Ffz, HV_BINOP_MULTIPLY, 1, m, &cBinop_eOLR9Ffz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3X0PVquk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1leOqzwO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0DB2KpeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yIYgqFJk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yIYgqFJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2X0XGcuF_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_l70seWgW, m);
}

void Heavy_WSTD_FL3NGR::cBinop_2X0XGcuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WNAgUhqY, m);
}

void Heavy_WSTD_FL3NGR::cMsg_LGRIOEPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9wcXf5TC, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_juHjH49v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_SyNUF6iC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_rsyeFEUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ccy15UVi_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_qMEnVGYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_juHjH49v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Lq0oB3qZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hCdU8bbP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hCdU8bbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tXSEfczX, HV_BINOP_MULTIPLY, 1, m, &cBinop_tXSEfczX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ccy15UVi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Lq0oB3qZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_tXSEfczX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bBe9pazH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SyNUF6iC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tXSEfczX, HV_BINOP_MULTIPLY, 0, m, &cBinop_tXSEfczX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_bBe9pazH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cmEIlbXH, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_iCQdgSl5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_4bokiZ2v_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4bokiZ2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rsyeFEUt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qMEnVGYz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Ph80dI0U_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3obatd09, 0, m, &cSlice_3obatd09_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ScE68poZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_3obatd09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vhnOBCot_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vhnOBCot_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_3HWrAzEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vhnOBCot_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_vhnOBCot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uvFMyu91_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_ScE68poZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JDd608YO, 0, m, &cSlice_JDd608YO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tdsmV5nX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_JDd608YO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pWe2GafJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pWe2GafJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_VMI6pSzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pWe2GafJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_pWe2GafJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1Ga11imP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_tdsmV5nX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ycHwTbsA, 0, m, &cSlice_ycHwTbsA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Udj8nycj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_ycHwTbsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LagChXgf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LagChXgf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_9PIynrgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LagChXgf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_LagChXgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jK7MEz08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Udj8nycj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uITReHf0, 0, m, &cSlice_uITReHf0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_uITReHf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AETJXZdq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AETJXZdq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_TTi9r5pC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AETJXZdq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_AETJXZdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ETlfEQAF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_HGujQv59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S2TmLJbK, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jHkCXgOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e5nphpH0, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_zSiMbc2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_9zn0Qwhw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9zn0Qwhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_k2ZN1e4W, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_bsOf0pxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DBiGuuw0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_DBiGuuw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OTRfPWnP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_nZRM7LoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XDPR17tH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_1Z5TITvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_CNoagOd9_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rMgXQ0Um, m);
}

void Heavy_WSTD_FL3NGR::cBinop_OTRfPWnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rdmqZwk6, m);
}

void Heavy_WSTD_FL3NGR::cMsg_XDPR17tH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1Z5TITvC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_CNoagOd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zz2fk708, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wKAEbnhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_WHeRhxFG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_WHeRhxFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SCv4b3TA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_sBJeMWkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ybIz7Enj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_Elw3WTrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SMyNKN0p_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QHNN0mgH, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SCv4b3TA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qjpHCObj, m);
}

void Heavy_WSTD_FL3NGR::cMsg_ybIz7Enj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Elw3WTrG_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_SMyNKN0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_0INIjNCr, m);
}

void Heavy_WSTD_FL3NGR::cBinop_u7jbqg5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Fb2mAAqE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Fb2mAAqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_vMgN0RkP_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_D5mQA6B0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wPYUsitw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_RdKfNria_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_juTBDkTB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_vMgN0RkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_faxlf8BO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_faxlf8BO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ClX9Fwsk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cFdHPIHo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_ClX9Fwsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KCy07KqD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_cFdHPIHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EW5iqT6w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_KCy07KqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fSYtOb59_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_EW5iqT6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fPB69kid_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fPB69kid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_V25laMom_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_fSYtOb59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_D5mQA6B0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_V25laMom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_RdKfNria_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pO6yoE10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_htwavoM1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_htwavoM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S4V0fXth_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_IeHeYdw9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VRF6MfbI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_VRF6MfbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_FVbD64Bk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_HY1pfgEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HY1pfgEZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VKfwQCZE, 0, m, &cDelay_VKfwQCZE_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HY1pfgEZ, 0, m, &cDelay_HY1pfgEZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_h4uV5VZS, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_VKfwQCZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VKfwQCZE, m);
  cMsg_OomTRpb5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_LGZigsPr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_KoFi7TRH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_AChjJ0jB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_46dlV8MN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_fUllEQbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_enFmrN97_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_HY1pfgEZ, 2, m, &cDelay_HY1pfgEZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0hRquB0j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_46dlV8MN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_fUllEQbq, 0, m, &hTable_fUllEQbq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_FVbD64Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_AChjJ0jB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OomTRpb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_fUllEQbq, 0, m, &hTable_fUllEQbq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_0hRquB0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HY1pfgEZ, 0, m, &cDelay_HY1pfgEZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_enFmrN97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VKfwQCZE, 2, m, &cDelay_VKfwQCZE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KoFi7TRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_h4uV5VZS, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_GXoTEHHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rNlXG36K_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_rNlXG36K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_NEsD2IUH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_ENBXQCpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ENBXQCpc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9GP1ZNsn, 0, m, &cDelay_9GP1ZNsn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ENBXQCpc, 0, m, &cDelay_ENBXQCpc_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CYmqKX1m, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_9GP1ZNsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9GP1ZNsn, m);
  cMsg_3B6D3md4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_RNkLWKk9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_xwaTFxiF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_dWPQ3I9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_thuDcXpf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_jPIHCBKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fQWta2Px_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ENBXQCpc, 2, m, &cDelay_ENBXQCpc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K2WY15UB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_thuDcXpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_jPIHCBKs, 0, m, &hTable_jPIHCBKs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NEsD2IUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_dWPQ3I9C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_3B6D3md4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_jPIHCBKs, 0, m, &hTable_jPIHCBKs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_K2WY15UB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ENBXQCpc, 0, m, &cDelay_ENBXQCpc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fQWta2Px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9GP1ZNsn, 2, m, &cDelay_9GP1ZNsn_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_xwaTFxiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CYmqKX1m, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_zwONcVna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aHy2outF, HV_BINOP_MULTIPLY, 0, m, &cBinop_aHy2outF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_y4h8rHNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sSzUEU17_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_sSzUEU17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uMvbwSUc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_aHy2outF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hOMi1Qgp_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_yFbHgAPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aHy2outF, HV_BINOP_MULTIPLY, 1, m, &cBinop_aHy2outF_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_uMvbwSUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yFbHgAPY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hOMi1Qgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YsoIV7Sv_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_YsoIV7Sv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_B4LylwRZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_La8VuNlH, m);
}

void Heavy_WSTD_FL3NGR::cBinop_B4LylwRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wR8eTwX5, m);
}

void Heavy_WSTD_FL3NGR::cVar_Z8jSKoEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_22X70zpM, HV_BINOP_MULTIPLY, 0, m, &cBinop_22X70zpM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_7qvEyrPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZG2qzxzj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_ZG2qzxzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d1PcSc1g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_22X70zpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_uXn9V6HS_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oDjSAjP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_22X70zpM, HV_BINOP_MULTIPLY, 1, m, &cBinop_22X70zpM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_d1PcSc1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oDjSAjP4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_uXn9V6HS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_A8FgUJVQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_A8FgUJVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_h0Sj2xSG_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_AEAnBpC8, m);
}

void Heavy_WSTD_FL3NGR::cBinop_h0Sj2xSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fMrJgR9a, m);
}

void Heavy_WSTD_FL3NGR::cMsg_S4V0fXth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UsJOItPc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_CfXgIO7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_D7Fi76o5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_2BMZEyJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_WSVoe2NV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_7PcTvsfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_CfXgIO7X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_VMBIzgd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0pgTIBwc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0pgTIBwc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Io5eRgfO, HV_BINOP_MULTIPLY, 1, m, &cBinop_Io5eRgfO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_WSVoe2NV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_VMBIzgd1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Io5eRgfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RIs3FxYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_D7Fi76o5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Io5eRgfO, HV_BINOP_MULTIPLY, 0, m, &cBinop_Io5eRgfO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_RIs3FxYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FHjyf8fD, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_lUipQbL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_Mu8jHOSo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_Mu8jHOSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2BMZEyJf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7PcTvsfa_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_JxKv5bdN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Aht2PN5l, 0, m, &cSlice_Aht2PN5l_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mFTtiCXi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_Aht2PN5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kK3SjvyH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kK3SjvyH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_m5G3vjzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kK3SjvyH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_kK3SjvyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ue1wnmRI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_mFTtiCXi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lyqhmJo1, 0, m, &cSlice_lyqhmJo1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Bwn5k6Ea_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_lyqhmJo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_C8ibEHR5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_C8ibEHR5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_GXxn0b2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C8ibEHR5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_C8ibEHR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_t2V9UH2y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_Bwn5k6Ea_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lfAESBiO, 0, m, &cSlice_lfAESBiO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pi8s6AgV_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_lfAESBiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iX4aRuc5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iX4aRuc5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_SL2E4lXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iX4aRuc5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_iX4aRuc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nokKSX4g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_pi8s6AgV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_R20BOjbm, 0, m, &cSlice_R20BOjbm_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_R20BOjbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KhKQnCBp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KhKQnCBp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_SEbAPOEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KhKQnCBp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_KhKQnCBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_H8wKqsqv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wPYUsitw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fyLT8u6R, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_juTBDkTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DP1WKi1L, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_9MPtvniU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_6AOJgbjt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_6AOJgbjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_PgQCWqpR, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_dFWqxHXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MgB1LSNe_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_MgB1LSNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_zhqLATFO_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_Vjsxfq5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h4ySbC0X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_UTnUa2C7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ILEDaIpk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iOPbRv3N, m);
}

void Heavy_WSTD_FL3NGR::cBinop_zhqLATFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_pL7I6NWd, m);
}

void Heavy_WSTD_FL3NGR::cMsg_h4ySbC0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UTnUa2C7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_ILEDaIpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_VX9qf3Qs, m);
}

void Heavy_WSTD_FL3NGR::cMsg_wVcEKTQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DJNLDt3q_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_DJNLDt3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_qLvv3Bwb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cVar_h0SKcYOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MxbKGWeV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSystem_jJaFdfaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_itGoegbz_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_h9QfJkcA, m);
}

void Heavy_WSTD_FL3NGR::cBinop_qLvv3Bwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_r8phHBBk, m);
}

void Heavy_WSTD_FL3NGR::cMsg_MxbKGWeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jJaFdfaj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_itGoegbz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Dhx4tDb0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_r0RB6pB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qCkDXwWU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_qCkDXwWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Y0tOKKuQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cUnop_98hSOPuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1M9VleSf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cUnop_fSvYflGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Hl8LsuVL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_Y0tOKKuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_lLcAV1ul_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_lLcAV1ul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QWcPdA0v_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ly4nofzT_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_QWcPdA0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xo6zkvLC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_Ly4nofzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bru3qCGt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_xo6zkvLC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pNG6yF2r_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_Bru3qCGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BOd2OzX5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BOd2OzX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0mj4CQuh_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pNG6yF2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_98hSOPuV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0mj4CQuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_fSvYflGg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rSrg8elU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_NJXtuHb6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_NJXtuHb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S2Yvs9D4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_zqX3idxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sivl2tjH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_sivl2tjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7BDMSlMC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_GB5nDq3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GB5nDq3m, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0WYkkwaj, 0, m, &cDelay_0WYkkwaj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GB5nDq3m, 0, m, &cDelay_GB5nDq3m_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gPeJCxYv, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_0WYkkwaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0WYkkwaj, m);
  cMsg_fHxaW17x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_XrIl1ZGf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_KxqeSiVz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_c61K18XD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cCf5Hk5b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_5mJknyI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UQiUmES2_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GB5nDq3m, 2, m, &cDelay_GB5nDq3m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fd9eBLLf_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_cCf5Hk5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_5mJknyI3, 0, m, &hTable_5mJknyI3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_7BDMSlMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_c61K18XD_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_fHxaW17x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_5mJknyI3, 0, m, &hTable_5mJknyI3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_fd9eBLLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GB5nDq3m, 0, m, &cDelay_GB5nDq3m_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_UQiUmES2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_0WYkkwaj, 2, m, &cDelay_0WYkkwaj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_KxqeSiVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_gPeJCxYv, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_yXPcf3Rl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Dk5JfAOk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_Dk5JfAOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oIjuVwFu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cDelay_5G2lgwua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5G2lgwua, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bohiRGaj, 0, m, &cDelay_bohiRGaj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5G2lgwua, 0, m, &cDelay_5G2lgwua_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rrn5iIFw, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cDelay_bohiRGaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bohiRGaj, m);
  cMsg_oKDpApFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_bzit6yl2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_c9rB5WIW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cBinop_Mz2kpxsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oQOeQsz3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::hTable_exYt3KeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nJ5HGVCI_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5G2lgwua, 2, m, &cDelay_5G2lgwua_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EIWClyuC_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oQOeQsz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_exYt3KeQ, 0, m, &hTable_exYt3KeQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_oIjuVwFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_Mz2kpxsk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_oKDpApFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_exYt3KeQ, 0, m, &hTable_exYt3KeQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_EIWClyuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5G2lgwua, 0, m, &cDelay_5G2lgwua_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_nJ5HGVCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_bohiRGaj, 2, m, &cDelay_bohiRGaj_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_c9rB5WIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rrn5iIFw, 1, m, NULL);
}

void Heavy_WSTD_FL3NGR::cVar_Ps1iK0l3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lAmRqm1E, HV_BINOP_MULTIPLY, 0, m, &cBinop_lAmRqm1E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_k9y7VqpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rHJsWzpm_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_rHJsWzpm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LqGAy5Yw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_lAmRqm1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_TSbYE8vU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_0zkXC15V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lAmRqm1E, HV_BINOP_MULTIPLY, 1, m, &cBinop_lAmRqm1E_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_LqGAy5Yw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0zkXC15V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TSbYE8vU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_nzGDNIZQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_nzGDNIZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SoryrE9s_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_j42Uhmfq, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SoryrE9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bhhvqNdD, m);
}

void Heavy_WSTD_FL3NGR::cVar_KtyTmzdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EvcUTUT7, HV_BINOP_MULTIPLY, 0, m, &cBinop_EvcUTUT7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_XLy87xkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fuwdvBv9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSystem_fuwdvBv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aLMCH5It_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_EvcUTUT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_EeE3jxj0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_rp32WNYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EvcUTUT7, HV_BINOP_MULTIPLY, 1, m, &cBinop_EvcUTUT7_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_aLMCH5It_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rp32WNYo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_EeE3jxj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4OcRRrL1_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_4OcRRrL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_SK6pGTZd_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WEMJuxTY, m);
}

void Heavy_WSTD_FL3NGR::cBinop_SK6pGTZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_6uUX7HCw, m);
}

void Heavy_WSTD_FL3NGR::cMsg_S2Yvs9D4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ow4dWtIc, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cUnop_4lHdghjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_DjkPJhAV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_YsnJ6E4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_TAwpO9sQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cCast_T65UgeKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_4lHdghjH_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_BswxPcx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_v7JQ4W3F_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_v7JQ4W3F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8FtXUwIV, HV_BINOP_MULTIPLY, 1, m, &cBinop_8FtXUwIV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TAwpO9sQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_BswxPcx3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_8FtXUwIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_163TIawh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cBinop_DjkPJhAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8FtXUwIV, HV_BINOP_MULTIPLY, 0, m, &cBinop_8FtXUwIV_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_163TIawh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EqgGYvDv, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_UTPtaHio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_9gwY57S0_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_9gwY57S0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YsnJ6E4y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T65UgeKq_sendMessage);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_sEO23pW7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5AEIh4XR, 0, m, &cSlice_5AEIh4XR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XNwqjwml_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_5AEIh4XR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yOSltzKB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yOSltzKB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_FgVn4JK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yOSltzKB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_yOSltzKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZfyA8EdR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_XNwqjwml_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vVJNKGYB, 0, m, &cSlice_vVJNKGYB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vIqqHGLZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_vVJNKGYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_uZa5Dcvw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_uZa5Dcvw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_RBQ3tLw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uZa5Dcvw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_uZa5Dcvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l66dHcd8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_vIqqHGLZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xTv4Qohj, 0, m, &cSlice_xTv4Qohj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GgOo7LWW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_xTv4Qohj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8kqtmZYe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8kqtmZYe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_5Cbo5sq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8kqtmZYe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_8kqtmZYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iCDn2tAb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSwitchcase_GgOo7LWW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gjlsqZ22, 0, m, &cSlice_gjlsqZ22_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FL3NGR::cSlice_gjlsqZ22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vYb9231m_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vYb9231m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FL3NGR::cVar_paaCci6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vYb9231m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cSend_vYb9231m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qLPcCDlF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cMsg_1M9VleSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zehEva0Q, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_Hl8LsuVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MLud7rFv, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_cYuK85fD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xVwmYzDR_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_By4EXSBZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_9TeTvhfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xVwmYzDR_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_By4EXSBZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_2aRVogqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xVwmYzDR_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_By4EXSBZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_A7xlGZnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xVwmYzDR_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_By4EXSBZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_0CRMu3op_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_xVwmYzDR_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_By4EXSBZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_hJvRZPCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Evw0V7ZQ, 0, m, &cVar_Evw0V7ZQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_HsIxqdYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_uVpAyZE8, 0, m, &cVar_uVpAyZE8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zkFL5DoZ, 0, m, &cVar_zkFL5DoZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vCJCIC6V, 0, m, &cVar_vCJCIC6V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_daeH7N23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ph80dI0U_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_snxCpzBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ph80dI0U_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_930Zz87L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ph80dI0U_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_MnNhWrTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_Ph80dI0U_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ynPo15a5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TbHSNimL, 0, m, &cVar_TbHSNimL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_hl956zQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P1qC9Njg, 0, m, &cVar_P1qC9Njg_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_zjcUl531_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sp3YIHOX, 0, m, &cVar_sp3YIHOX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_VZjCI4TN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JxKv5bdN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_8gLoq7lQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JxKv5bdN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_OQ4rk5Rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JxKv5bdN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_QOUxifJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_JxKv5bdN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_ut9xoLZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xYo12C79, 0, m, &cVar_xYo12C79_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_bX035ZZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QMuCi2lx, 0, m, &cVar_QMuCi2lx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_pcKdmBAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2MCnAFpo, 0, m, &cVar_2MCnAFpo_sendMessage);
}

void Heavy_WSTD_FL3NGR::cMsg_OGrpmK5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sEO23pW7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_PTZX5AJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sEO23pW7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_sKchadZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sEO23pW7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cMsg_jOJQ8WEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sEO23pW7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FL3NGR::cBinop_0GoaR6MY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GieRInnz, 0, m, &cVar_GieRInnz_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_cY1nMJB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jRp1SfMt, 0, m, &cVar_jRp1SfMt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cBinop_TcZUFzdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wIC8CdJB, 0, m, &cVar_wIC8CdJB_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0GxTb224_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uVpAyZE8, 0, m, &cVar_uVpAyZE8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_HPYxLmtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zkFL5DoZ, 0, m, &cVar_zkFL5DoZ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qgrsReJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vCJCIC6V, 0, m, &cVar_vCJCIC6V_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qKUEQ3J2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wg7Jbenc, 0, m, &cVar_wg7Jbenc_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_lihC8wyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mEgSHdih_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5efE1rX2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Pgwg6mPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yCwy3TuU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1RQYLVfl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hz17NUx2_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_8WfXf7LH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_imW0R7mc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2bUCqo1N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oE9b7BRU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_c93YVyUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0GVnQPGP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fpQlCjwA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LSvtqxmw_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_GRn6k9uj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_noDZIIJD_sendMessage(_c, 0, m);
  cMsg_W3ZGrbIq_sendMessage(_c, 0, m);
  cMsg_hHctbQCS_sendMessage(_c, 0, m);
  cMsg_FDBchqbF_sendMessage(_c, 0, m);
  cMsg_eVhOODDP_sendMessage(_c, 0, m);
  cMsg_rr20vKzW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fLEAIpyl, 0, m, &cVar_fLEAIpyl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wg7Jbenc, 0, m, &cVar_wg7Jbenc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HYlG5tgN, 0, m, &cVar_HYlG5tgN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8kVmapEU, 0, m, &cVar_8kVmapEU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ViQzFV0J, 0, m, &cVar_ViQzFV0J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P1l6h1vb, 0, m, &cVar_P1l6h1vb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3L4XG43Q, 0, m, &cVar_3L4XG43Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wMl3bmMU, 0, m, &cVar_wMl3bmMU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GDKgqdCZ, 0, m, &cVar_GDKgqdCZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0yPe5rAz, 0, m, &cVar_0yPe5rAz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6chdap7p, 0, m, &cVar_6chdap7p_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_P6L3Kqte, 0, m, &cVar_P6L3Kqte_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YPfyIPsZ, 0, m, &cVar_YPfyIPsZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1qsej3pM, 0, m, &cVar_1qsej3pM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_d4KYBiIG, 0, m, &cVar_d4KYBiIG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8ihbOjID, 0, m, &cVar_8ihbOjID_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7fAfAH0s, 0, m, &cVar_7fAfAH0s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7Taz0BLy, 0, m, &cVar_7Taz0BLy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QBHJCxBU, 0, m, &cVar_QBHJCxBU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kei45EjP, 0, m, &cVar_kei45EjP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZeIMwCRP, 0, m, &cVar_ZeIMwCRP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0g5of0Na, 0, m, &cVar_0g5of0Na_sendMessage);
  cMsg_jqFfaVtu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uPUsXlgc, 0, m, &cVar_uPUsXlgc_sendMessage);
  cMsg_4XJD27cu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CVqxGADU, 0, m, &cVar_CVqxGADU_sendMessage);
  cMsg_y4h8rHNd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_zwONcVna, 0, m, &cVar_zwONcVna_sendMessage);
  cMsg_7qvEyrPM_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Z8jSKoEL, 0, m, &cVar_Z8jSKoEL_sendMessage);
  cMsg_k9y7VqpF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Ps1iK0l3, 0, m, &cVar_Ps1iK0l3_sendMessage);
  cMsg_XLy87xkx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KtyTmzdw, 0, m, &cVar_KtyTmzdw_sendMessage);
  cMsg_dsAZGdZk_sendMessage(_c, 0, m);
  cMsg_eOjDN6Aa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3HWrAzEc, 0, m, &cVar_3HWrAzEc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VMI6pSzx, 0, m, &cVar_VMI6pSzx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9PIynrgJ, 0, m, &cVar_9PIynrgJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TTi9r5pC, 0, m, &cVar_TTi9r5pC_sendMessage);
  cMsg_IeHeYdw9_sendMessage(_c, 0, m);
  cMsg_GXoTEHHm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_m5G3vjzU, 0, m, &cVar_m5G3vjzU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GXxn0b2l, 0, m, &cVar_GXxn0b2l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SL2E4lXt, 0, m, &cVar_SL2E4lXt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SEbAPOEw, 0, m, &cVar_SEbAPOEw_sendMessage);
  cMsg_zqX3idxk_sendMessage(_c, 0, m);
  cMsg_yXPcf3Rl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_FgVn4JK2, 0, m, &cVar_FgVn4JK2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RBQ3tLw5, 0, m, &cVar_RBQ3tLw5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5Cbo5sq9, 0, m, &cVar_5Cbo5sq9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_paaCci6I, 0, m, &cVar_paaCci6I_sendMessage);
  cMsg_HsIxqdYd_sendMessage(_c, 0, m);
  cMsg_hJvRZPCI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_91G1z4Rr, 0, m, &cVar_91G1z4Rr_sendMessage);
  cMsg_texMxWsH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_aZMGsB6G, 0, m, &cVar_aZMGsB6G_sendMessage);
  cMsg_MY9yTgcp_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_nZRM7LoB, 0, m, &cVar_nZRM7LoB_sendMessage);
  cMsg_bsOf0pxP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_sBJeMWkd, 0, m, &cVar_sBJeMWkd_sendMessage);
  cMsg_wKAEbnhd_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Vjsxfq5i, 0, m, &cVar_Vjsxfq5i_sendMessage);
  cMsg_dFWqxHXA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_h0SKcYOd, 0, m, &cVar_h0SKcYOd_sendMessage);
  cMsg_wVcEKTQX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_oy2Q0rcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Dsb2Fbs, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Dsb2Fbs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_HI2ghAPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_VTYSDQZS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1DIrnjdu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Q9B4GpjV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_EJiDhjXx_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_JlrFuOrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ABvS3Mcx_sendMessage);
  cMsg_renD3vcK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_2KlNO53G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ss9NsmPM, HV_BINOP_MULTIPLY, 0, m, &cBinop_ss9NsmPM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_h9FXIWdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_nVN2SG4R_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_cHHYr6yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jxyy9AKr, HV_BINOP_MULTIPLY, 1, m, &cBinop_jxyy9AKr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_W0wQ6mj0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_2jnZaWXu_sendMessage);
  cMsg_OpuvSkVk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_1W7TuWy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m0QIbzbE, HV_BINOP_MULTIPLY, 0, m, &cBinop_m0QIbzbE_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_NHXc6Znm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3r0YNVFp_sendMessage(_c, 0, m);
  cMsg_SgChnnLH_sendMessage(_c, 0, m);
  cMsg_VkETzEk6_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_MLbNotrt_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_birnfPZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fzn1yNgz_sendMessage);
  cMsg_PHhSZYAp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_6lLVK5kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ViQzFV0J, 0, m, &cVar_ViQzFV0J_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_0kt9qIFp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GZM0gAdz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ra6cWvL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_zsqz5CAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ULcd8pri_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O5awPh5h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k2ibUfZM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_vV12V56D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Au7qtCgj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fpYrZVeD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sitpRwH6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SyjxstBe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5xPwYhok_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_785GyDob_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J6C9t2vL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_bYvFE1IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XU4G9YZ9, HV_BINOP_MULTIPLY, 0, m, &cBinop_XU4G9YZ9_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_wsJm63q5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4gqMnCst_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ns3cxIlC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YU1Yu0Ht_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_f2uOaqYb_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1VySlQuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_TTbknGb7_sendMessage);
  cMsg_ThwSu5Cm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_K0zSDMN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5Z2kHeBM, HV_BINOP_MULTIPLY, 0, m, &cBinop_5Z2kHeBM_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Mhf4fwkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_tlDwY3Rs_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_4Hp4Txwg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HMAf7Q0m, HV_BINOP_MULTIPLY, 1, m, &cBinop_HMAf7Q0m_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_nOWrrhpQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jMLbcf4M_sendMessage);
  cMsg_yCDUmhTl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_5jPPVl6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PMlh3FMJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_PMlh3FMJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_XrtVK6S3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pYTUzail_sendMessage(_c, 0, m);
  cMsg_BTZ0VgKK_sendMessage(_c, 0, m);
  cMsg_nrYvd3Af_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_gvlg88xJ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_VQEAbYTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3yz4HznV_sendMessage);
  cMsg_Y5nkWHlq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FL3NGR::cReceive_UJHt547h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Evw0V7ZQ, 0, m, &cVar_Evw0V7ZQ_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_LW6UYRnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ynPo15a5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_yDC7WQzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hl956zQI_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_kJe3oD2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GBb4yB8X, 0, m, &cVar_GBb4yB8X_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_QhyDOSvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_zjcUl531_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_fjeifgMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ut9xoLZk_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_b2I8tzQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_bX035ZZL_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_w5UG4p23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zQNoWIc4, 0, m, &cVar_zQNoWIc4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uAOZoOf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_pcKdmBAu_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_A47uVLDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_0GoaR6MY_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_dhLnROco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_cY1nMJB6_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_SHFPsb57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h6F9cas4, 0, m, &cVar_h6F9cas4_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_AiYOML0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_TcZUFzdX_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_jK7MEz08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_TSav43td_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_1Ga11imP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_iCQdgSl5_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ETlfEQAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_mjz3kPfA_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_uvFMyu91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_N6RWrVf3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_nokKSX4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_zSiMbc2C_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_t2V9UH2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lUipQbL8_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_H8wKqsqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_u7jbqg5j_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_Ue1wnmRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pO6yoE10_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_iCDn2tAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_9MPtvniU_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_l66dHcd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_UTPtaHio_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_qLPcCDlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_r0RB6pB3_sendMessage);
}

void Heavy_WSTD_FL3NGR::cReceive_ZfyA8EdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_rSrg8elU_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FL3NGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_h9XYNFRf, VOf(Bf0));
    __hv_line_f(&sLine_wBM5C2iq, VOf(Bf1));
    __hv_line_f(&sLine_E10YTG2v, VOf(Bf2));
    __hv_line_f(&sLine_FP1y673P, VOf(Bf3));
    __hv_line_f(&sLine_HIYJ00HM, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_FRtlYWeK, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_WPoutDy8, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_fUcCzQbt, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_gtqpY1Mq, VOf(Bf1));
    __hv_line_f(&sLine_k8b47TYc, VOf(Bf0));
    __hv_line_f(&sLine_624nJyVR, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_YEXqnzgC, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_EvPReawm, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_TmqnO8TC, VOf(Bf5));
    __hv_line_f(&sLine_dDME5tZl, VOf(Bf1));
    __hv_line_f(&sLine_17mxWgEB, VOf(Bf2));
    __hv_line_f(&sLine_hXN8FsA3, VOf(Bf4));
    __hv_line_f(&sLine_59pETihH, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_962gDsHJ, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_dovMLsnx, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Aktkxcce, VOf(Bf6));
    __hv_line_f(&sLine_3mHnlXnM, VOf(Bf2));
    __hv_line_f(&sLine_P91c108O, VOf(Bf1));
    __hv_line_f(&sLine_gikfnGzI, VOf(Bf5));
    __hv_line_f(&sLine_iTgM2ijW, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_p6zxscl9, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_zazBS8NY, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_EJoJnBJt, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_lPsLHcxU, VOf(Bf2));
    __hv_line_f(&sLine_9z8jmUoA, VOf(Bf6));
    __hv_line_f(&sLine_DaCKeQfS, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_g4MB6TXs, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_7jecEgCm, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_ALBNZ6Ug, VOf(Bf8));
    __hv_line_f(&sLine_Rw3MiDJA, VOf(Bf2));
    __hv_line_f(&sLine_PDUR6Oga, VOf(Bf1));
    __hv_line_f(&sLine_aFHpFC2I, VOf(Bf7));
    __hv_line_f(&sLine_DBepuiNk, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_eSkh65fu, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_0VR2a120, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_e5nphpH0, VOf(Bf9));
    __hv_phasor_k_f(&sPhasor_Esxz9yMm, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf8), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_9wcXf5TC, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf10), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf1), VIf(Bf10), VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf8));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf8));
    __hv_varread_f(&sVarf_1KFBptOr, VOf(Bf2));
    __hv_mul_f(VIf(Bf8), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_vTkzWq5v, VOf(Bf8));
    __hv_rpole_f(&sRPole_mFIqWPRb, VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_l70seWgW, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_WNAgUhqY, VOf(Bf10));
    __hv_rpole_f(&sRPole_1rf5yC0Y, VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_FifwOZDR, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_uDfhR1dW, VOf(Bf1));
    __hv_mul_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_VApOf2eL, VOf(Bf10));
    __hv_min_f(VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf10), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_wpfW3PB5, VOf(Bf10));
    __hv_zero_f(VOf(Bf11));
    __hv_lt_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_and_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_cast_fi(VIf(Bf11), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_oTzaTaVy, VIi(Bi1), VOf(Bf11));
    __hv_tabread_if(&sTabread_gLN0mO8w, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf11), VIf(Bf10), VOf(Bf11));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf11), VIf(Bf2), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_S2TmLJbK, VOf(Bf2));
    __hv_mul_f(VIf(Bf10), VIf(Bf2), VOf(Bf11));
    __hv_fma_f(VIf(Bf3), VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_tabhead_f(&sTabhead_OiI1gBY8, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_RF5cQhEN, VOf(Bf1));
    __hv_mul_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_15Y4tSEc, VOf(Bf8));
    __hv_min_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf8), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf12));
    __hv_varread_f(&sVarf_oojM5twO, VOf(Bf8));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf8), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_B1lWH8Te, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_hUUPpvUZ, VIi(Bi0), VOf(Bf8));
    __hv_sub_f(VIf(Bf13), VIf(Bf8), VOf(Bf13));
    __hv_sub_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf8), VOf(Bf8));
    __hv_mul_f(VIf(Bf2), VIf(Bf8), VOf(Bf2));
    __hv_fma_f(VIf(Bf9), VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_cmEIlbXH, VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf8), VIf(Bf5), VOf(Bf5));
    __hv_tabwrite_f(&sTabwrite_LRwvX4DO, VIf(Bf5));
    __hv_fma_f(VIf(Bf10), VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_4n3fj4yb, VIf(Bf3));
    __hv_varwrite_f(&sVarf_6Z6VCamE, VIf(Bf11));
    __hv_line_f(&sLine_DP1WKi1L, VOf(Bf11));
    __hv_phasor_k_f(&sPhasor_k2ZN1e4W, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_abs_f(VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf3), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf9), VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_UsJOItPc, VOf(Bf3));
    __hv_var_k_f(VOf(Bf9), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf10));
    __hv_add_f(VIf(Bf10), VIf(Bf5), VOf(Bf10));
    __hv_varread_f(&sVarf_La8VuNlH, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_wR8eTwX5, VOf(Bf10));
    __hv_rpole_f(&sRPole_ARzVmkKA, VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_AEAnBpC8, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_fMrJgR9a, VOf(Bf5));
    __hv_rpole_f(&sRPole_VgwjQd49, VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_AzfW6dpt, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf9), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_rdmqZwk6, VOf(Bf3));
    __hv_mul_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_zz2fk708, VOf(Bf5));
    __hv_min_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf9), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf9));
    __hv_varread_f(&sVarf_rMgXQ0Um, VOf(Bf5));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf5), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_eVCdCPUq, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_QsRoH593, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf8), VIf(Bf5), VOf(Bf8));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf8), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_fyLT8u6R, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf8));
    __hv_fma_f(VIf(Bf0), VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_tabhead_f(&sTabhead_mnQ5iKXj, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_qjpHCObj, VOf(Bf3));
    __hv_mul_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_0INIjNCr, VOf(Bf10));
    __hv_min_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf12));
    __hv_varread_f(&sVarf_QHNN0mgH, VOf(Bf10));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_Rv7TfEmu, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_vC02TxmK, VIi(Bi0), VOf(Bf10));
    __hv_sub_f(VIf(Bf13), VIf(Bf10), VOf(Bf13));
    __hv_sub_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf9));
    __hv_fma_f(VIf(Bf11), VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_FHjyf8fD, VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_tabwrite_f(&sTabwrite_h4uV5VZS, VIf(Bf6));
    __hv_fma_f(VIf(Bf5), VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_CYmqKX1m, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Fbq4FqgX, VIf(Bf8));
    __hv_line_f(&sLine_MLud7rFv, VOf(Bf8));
    __hv_phasor_k_f(&sPhasor_PgQCWqpR, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_ow4dWtIc, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf5));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf5));
    __hv_varread_f(&sVarf_j42Uhmfq, VOf(Bf11));
    __hv_mul_f(VIf(Bf5), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_bhhvqNdD, VOf(Bf5));
    __hv_rpole_f(&sRPole_4mvB96Ym, VIf(Bf11), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_WEMJuxTY, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_6uUX7HCw, VOf(Bf6));
    __hv_rpole_f(&sRPole_kY4qKT1f, VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_tabhead_f(&sTabhead_rmOvLFDg, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf11), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_pL7I6NWd, VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_VX9qf3Qs, VOf(Bf6));
    __hv_min_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf11));
    __hv_varread_f(&sVarf_iOPbRv3N, VOf(Bf6));
    __hv_zero_f(VOf(Bf10));
    __hv_lt_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_and_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_cast_fi(VIf(Bf10), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_TnEmLToP, VIi(Bi1), VOf(Bf10));
    __hv_tabread_if(&sTabread_i1RmdziK, VIi(Bi0), VOf(Bf6));
    __hv_sub_f(VIf(Bf10), VIf(Bf6), VOf(Bf10));
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_zehEva0Q, VOf(Bf11));
    __hv_mul_f(VIf(Bf6), VIf(Bf11), VOf(Bf10));
    __hv_fma_f(VIf(Bf4), VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_tabhead_f(&sTabhead_rCRrJcqw, VOf(Bf0));
    __hv_var_k_f_r(VOf(Bf12), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_varread_f(&sVarf_r8phHBBk, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_Dhx4tDb0, VOf(Bf5));
    __hv_min_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_zero_f(VOf(Bf0));
    __hv_max_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_sub_f(VIf(Bf12), VIf(Bf0), VOf(Bf0));
    __hv_floor_f(VIf(Bf0), VOf(Bf12));
    __hv_varread_f(&sVarf_h9QfJkcA, VOf(Bf5));
    __hv_zero_f(VOf(Bf13));
    __hv_lt_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_and_f(VIf(Bf5), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_cast_fi(VIf(Bf13), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_PKFILhJQ, VIi(Bi1), VOf(Bf13));
    __hv_tabread_if(&sTabread_sitp6Qqk, VIi(Bi0), VOf(Bf5));
    __hv_sub_f(VIf(Bf13), VIf(Bf5), VOf(Bf13));
    __hv_sub_f(VIf(Bf0), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf13), VIf(Bf12), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf11), VIf(Bf5), VOf(Bf11));
    __hv_fma_f(VIf(Bf8), VIf(Bf7), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_EqgGYvDv, VOf(Bf8));
    __hv_fma_f(VIf(Bf8), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_gPeJCxYv, VIf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_rrn5iIFw, VIf(Bf4));
    __hv_varwrite_f(&sVarf_A8fN3esW, VIf(Bf10));
    __hv_varwrite_f(&sVarf_dMWTBYqO, VIf(Bf2));
    __hv_varwrite_f(&sVarf_MQQVIybS, VIf(Bf9));
    __hv_varwrite_f(&sVarf_SannQb3C, VIf(Bf11));
    __hv_varread_f(&sVarf_6Z6VCamE, VOf(Bf11));
    __hv_varread_f(&sVarf_Fbq4FqgX, VOf(Bf9));
    __hv_varread_f(&sVarf_A8fN3esW, VOf(Bf2));
    __hv_add_f(VIf(Bf9), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_dMWTBYqO, VOf(Bf2));
    __hv_varread_f(&sVarf_MQQVIybS, VOf(Bf11));
    __hv_varread_f(&sVarf_SannQb3C, VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf2), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf9), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FL3NGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FL3NGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
